/*
#pragma ident "@(#)AddressObserver.java	1.3      96/11/02     SMI"

 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony;
import  java.telephony.events.AddrEv;

/**
 * The AddressObserver interface reports all state changes on the Address
 * object as events. Applications instantiate an object which implements
 * this interface and uses the <EM>Address.addObserver()</EM> method to begin
 * the delivery of events to this object. Applications may use the
 * <EM>Address.removeObserver()</EM> method to discontinue the delivery of
 * events to an observer object. A list of observers on the Address object can
 * be obtained via the <EM>Address.getObservers()</EM> method. Events will be
 * delivered to the AddressObserver interface only if the Provider is in the
 * Provider.IN_SERVICE state.
 * <p>
 * The AddressObserver interface has one method: <EM>addressChangedEvent()</EM>.
 * This method takes a single argument, an array of AddrEv objects. Applications
 * iterate over this array for the individual events. All Address events must
 * extend the java.telephony.events.AddrEv interface.
 * <p>
 * The AddressObserver reports a list of events because several state changes
 * may occur at once. To maintain the consistency between the state changes
 * in the call model and the events reported to the application, several
 * events may need to be delivered at once.
 * <p>
 * The AddressObserver interface reports the following events. The hyper-links
 * below provide access to the specifications for these events.
 * <p>
 * @see java.telephony.events.AddrEv
 */

public interface AddressObserver {

  /**
   * Reports all events on the AddressObserver interface. This method takes
   * an array of AddrEv object as its argument which reports all these state
   * changes which have occurred on the Address object.
   * <p>
   * @param eventList The list of Address events.
   */
  public void addressChangedEvent(AddrEv[] eventList);
}
