/*
#pragma ident "@(#)CallObserver.java	1.2      96/11/02     SMI"

 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony;
import  java.telephony.events.CallEv;

/**
 * The CallObserver interface reports all state changes on the Call
 * object as events. It also reports all state changes in Connections
 * and TerminalConnections which are associated with this Call. Applications
 * instantiate an object which implements this interface and uses the
 * <EM>Call.addObserver()</EM> method to begin the delivery of events to this
 * object. Applications may use the <EM>Call.removeObserver()</EM> method to
 * discontinue the delivery of events to an observer object. A list of
 * observers on the Call object can be obtained via the
 * <EM>Call.getObservers()</EM> method. Events will be delivered to the
 * CallObserver interface only if the Provider is in the Provider.IN_SERVICE
 * state.
 * <p>
 * The CallObserver interface has one method: <EM>callChangedEvent()</EM>.
 * This method takes a single argument, an array of CallEv objects. Applications
 * iterate over this array for the individual events. All Call, Connection,
 * and TerminalConnection events must extend the java.telephony.events.CallEv
 * interface.
 * <p>
 * The CallObserver reports a list of events because several state changes
 * may occur at once. To maintain the consistency between the state changes
 * in the call model and the events reported to the application, several
 * events may need to be delivered at once.
 * <p>
 * The CallObserver interface reports the following events. The hyper-links
 * below provide access to the specifications for these events.
 * <p>
 * @see java.telephony.events.CallEv
 * @see java.telephony.events.ConnEv
 * @see java.telephony.events.TermConnEv
 * @see java.telephony.events.CallActiveEv
 * @see java.telephony.events.CallInvalidEv
 * @see java.telephony.events.ConnAlertingEv
 * @see java.telephony.events.ConnConnectedEv
 * @see java.telephony.events.ConnCreatedEv
 * @see java.telephony.events.ConnDisconnectedEv
 * @see java.telephony.events.ConnFailedEv
 * @see java.telephony.events.ConnInProgressEv
 * @see java.telephony.events.ConnUnknownEv
 * @see java.telephony.events.TermConnActiveEv
 * @see java.telephony.events.TermConnCreatedEv
 * @see java.telephony.events.TermConnDroppedEv
 * @see java.telephony.events.TermConnPassiveEv
 * @see java.telephony.events.TermConnRingingEv
 */

public interface CallObserver {

  /**
   * Reports all events on the CallObserver interface. This method takes
   * an array of CallEv object as its argument which reports all these state
   * changes which have occurred on the Call, Connection, and TerminalConnection
   * object.
   * <p>
   * @param eventList The list of Call events.
   */
  public void callChangedEvent(CallEv[] eventList);
}
