/*
#pragma ident "@(#)InvalidObjectException.java	1.5      97/01/22     SMI"

 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony;

/**
 * The object on which the method exists is invalid. An invalid object
 * exception typically occurs when an internal error occurs which causes
 * this object to become invalid for unknown reasons. Typically, once
 * an object becomes invalid, it generally stays that way. This exception
 * indicates which call control object is invalid.
 */

public class InvalidObjectException extends Exception {

  private int _type;
  private Object _object;

  /**
   * The invalid object in question is the Provider
   */
  public static final int PROVIDER_OBJECT = 0;


  /**
   * The invalid object in question is the Call
   */
  public static final int CALL_OBJECT = 1;


  /**
   * The invalid object in question is the Connection
   */
  public static final int CONNECTION_OBJECT = 2;


  /**
   * The invalid object in question is the Terminal
   */
  public static final int TERMINAL_OBJECT = 3;


  /**
   * The invalid object in question is the Address
   */
  public static final int ADDRESS_OBJECT = 4;


  /**
   * The invalid object in question is the TerminalConnection
   */
  public static final int TERMINAL_CONNECTION_OBJECT = 5;


  /**
   * Constructor with no string.
   */
  public InvalidObjectException(Object object, int type) {
    super();
    _object = object;
    _type   = type;
  }


  /**
   * Constructor which takes a string description.
   */
  public InvalidObjectException(Object object, int type, String s) {
    super(s);
    _object = object;
    _type   = type;
  }


  /**
   * Returns the type of object in question
   * <p>
   * @return The type of object in question.
   */
  public int getObjectType() {
    return _type;
  }


  /**
   * Returns a generic pointer to the object which caused the exception.
   * <p>
   * @return The object which caused the exception.
   */
  public Object getObject() {
    return _object;
  }
}
