/*
#pragma ident "@(#)InvalidPartyException.java	1.3      97/01/22     SMI"

 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony;

/**
 * Indicates that a party given as an argument to the method call was invalid.
 * This may either be the originating party of a telephone call or the
 * destination party of a telephone call, or a transfer, etc.
 */

public class InvalidPartyException extends Exception {

  private int _type;

  /**
   * Indicates that the originating party was invalid.
   */
  public static final int ORIGINATING_PARTY = 0;

  /**
   * Indictes that the destiation party was invalid.
   */
  public static final int DESTINATION_PARTY = 1;


  /**
   * Constructor with no string.
   */
  public InvalidPartyException(int type) {
    super();
    _type = type;
  }


  /**
   * Constructor which takes a string description.
   */
  public InvalidPartyException(int type, String s) {
    super(s);
    _type = type;
  }


  /**
   * Returns the type of party.
   * <p>
   * @return The type of party.
   */
  public int getType() {
    return _type;
  }
}
