/*
#pragma ident "@(#)ACDAddress.java	1.7      97/01/23     SMI"

 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcenter;
import  java.telephony.*;

/**
 * The ACDAddress interface models an ACD Group for the ACD feature.
 * <p>
 * The ACD Group is a logical PBX extension, so it is being modeled by
 * an extended CallCenterAddress.
 * <p>
 * Connection to an ACDAddress is being modeled by ACDConnection, which
 * extends Connection.
 * <p>
 * The methods added return queue information as well as the agents logged
 * in or associated with the ACDAddress.
 * <p>
 * To observe state changes for the agents logged into the ACDAddress,
 * an application must use the methods Address.addObserver() and
 * Address.deleteObserver().
 * <p>
 * To observe Call related and Connection related state changes as events
 * an application must use the methods CallCenterAddress.addObserver() and
 * CallCenterAddress.deleteObserver().
 */

public interface ACDAddress extends CallCenterAddress {

  /**
   * This method returns the agents logged into the ACDAddress.
   */
  public Agent[] getLoggedOnAgents();
  
  /**
   * This method returns all agents associated with the ACDAddress.
   */
  public Agent[] getAssociatedAgents();
  
  /**
   * This method returns the number of calls queued to an ACDAddress.
   */
  public int getNumberQueued();
  
  /**
   * This method returns the oldest call queued to an ACDAddress.
   */
  public Call getOldestCallQueued();
  
  /**
   * This method returns the relative load of an ACDAddress queue.
   */
  public int getRelativeQueueLoad();
  
  /**
   * This method returns the estimated wait time for new calls
   * queued to an ACDAddress.
   */
  public int getQueueWaitTime();
  
  /**
   * This method returns the ACDManagerAddress that is associated
   * with this ACDAddress.
   * <p>
   * If no ACDManagerAddress is associated with this ACDAddress
   * the method returns null.
   * <p>
   * @exception PlatformException A platform-specific exception occurred.
   */
  public ACDManagerAddress getACDManagerAddress()
    throws PlatformException;
}
