/*
 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcenter;
import  java.telephony.*;

/**
 * The ACDConnection interface augments the core Connection class.
 * This interface either represents the relationship between a Call and
 * an ACDAddress directly or an extension of an
 * ACDManagerConnection (i.e. so-called "sub-connection" of the
 * ACDManagerConnection) which represents the relationship between a
 * Call, an ACDManagerAddress and an ACDAddress. The latter case is only
 * valid when the Call has arrived at an ACDManagerAddress and
 * the functionality of the ACDMangerAddress determines that it must
 * involve an ACDAddress in the Call as it is processing the call.
 * When the ACDConnection is associated with an ACDManagerConnection,
 * the core Connection method of getCall() will always return null because
 * the ACDConnection is represented in the call through the ACDManagerConnection
 * (i.e. the call.getConnections() method will only contain the associated
 * ACDManagerConnection).
 * <p>
 * Note: The core Connection method of getTerminalConnection() will
 *       always return a empty list because ACDAddresses do not have
 *       Terminals associated with them.
 * <p>
 * The following are the possible core Connection states presented by this
 * interface: IDLE, INPROGRESS, ALERTING, DISCONNECTED.
 * <p>
 * The following are the definitions for these states with respect to the
 * ACDAddress:
 * <p>
 * The IDLE state is defined similiarly here as it is in the core. The IDLE
 * state is the initial and transitory state for new ACDConnection objects.
 * <p>
 * The INPROGRESS state indicates that a ACDConnection is queued at a particular
 * ACDAddress. This will result when there are no agents available to
 * route the call to.
 * <p>
 * The ALERTING state indicates that the ACDConnection has arrived at a
 * particular ACDAddress. This state is only valid for ACDConnections
 * that are not associated with an ACDManagerConnection.
 * <p>
 * The DISCONNECTED state has the same definition as in the core.
 */

public interface ACDConnection {

  /**
   * Returns the ACDManagerConnection object associated with this ACDConnection.
   * This will return a null, if this ACDConnection is not an extension of the
   * ACDManagerConnection. Note: If an ACDManagerConnection is returned, the
   * core method of getCall will return null.
   * <p>
   * @return The ACDManagerConnection associated with this ACDConnection.
   * @exception PlatformException A platform-specific exception occurred.
   */
  public ACDManagerConnection getACDManagerConnection()
    throws PlatformException;
}
