/*
 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcenter;
import  java.telephony.Call;
import  java.telephony.CallObserver;

/**
 * The ACDManagerAddress interface models an ACD management control point
 * of one or more ACDAddresses. Call are presented to this address for
 * distribution to the appropriate agents of the ACDAddress(es)
 * which are associated with this ACDManagerAddress.
 * <p>
 * The ACD Manager is a logical PBX extension, so it is being modeled by
 * an extended CallCenterAddress.
 * <p>
 * Connection to an ACDAddress is being modeled by ACDManagerConnection, which
 * extends Connection.
 * <p>
 * The method added returns the ACDAddress(es) associated with this ACD
 * Manager.
 * <p>
 * To observe Call related, Connection related, TerminalConnection related,
 * state changes as events an application must use the methods
 * CallCenterAddress.addCallObserver() and CallCenterAddress.deleteCallObserver().
 */

public interface ACDManagerAddress extends CallCenterAddress {

    /**
     * This method returns the ACDAddesses associated with this
     * ACDManagerAddress.
     * @return The list of ACDAddresses associated with the ACDManagerAddress.
     * @exception Exception Some exception thrown.
     */
	public ACDAddress[] getACDAddresses();

}
