/*
 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcenter;
import  java.telephony.*;

/**
 * The ACDManagerConnection interface augments the core Connection class.
 * This interface represents the relationship between the Call and
 * ACDManagerAddress.
 * <p>
 * ACDManagerConnections may be viewed as a container for zero or more ACDConnection
 * objects. ACDManagerConnection objects represent the relationship between the Call and
 * the ACDManagerAddress, whereas ACDConnection objects represent the relationship
 * between the Call, the ACDManagerAddress and the ACDAddress.
 * An ACDManagerAddress only augments the Connection
 * to Call through an ACDConnection at an ACDAddress when it determines that
 * the Call should or can be serviced by the agents associated with the given ACDAddress.
 * This extension of the connection is based on the conditions at the
 * ACDManagerAddress.
 * <p>
 * Note: The core Connection method of getTerminalConnection() will
 *       always return a empty list because ACDManagerAddresses do not have
 *       Terminals associated with them.
 * <p>
 * The following are the possible core Connection states presented by this
 * interface: IDLE, ALERTING, FAILED, DISCONNECTED.
 * <p>
 * The following are the definitions for these states with respect to the
 * ACDManagerAddress:
 * <p>
 * The IDLE state is defined similiarly here as it is in the core. The IDLE
 * state is the initial and transitory state for new ACDManagerConnection objects.
 * <p>
 * The ALERTING state indicates that the ACDManagerConnection has arrived at a
 * particular ACD manager address.
 * <p>
 * The FAILED state has the same definition as in the core.
 * <p>
 * The DISCONNECTED state has the same definition as in the core.
 */

public interface ACDManagerConnection {


  /**
   * Returns the list of ACDConnection objects associated with this
   * ACDManagerConnection.
   * <p>
   * @return The list of ACDConnection associated with this ACDManagerConnection.
   * @exception PlatformException A platform-specific exception occurred.
   */
  public ACDConnection[] getACDConnections()
    throws PlatformException;
}
