/*
#pragma ident "@(#)AgentTerminal.java	1.6      97/01/22     SMI"

 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcenter;
import  java.telephony.callcontrol.CallControlTerminal;
import  java.telephony.PlatformException;
import  java.telephony.CallObserver;
import  java.telephony.callcenter.Agent;

/**
 * The AgentTerminal interface models an agent extension for the ACD
 * feature. AgentTerminal extends CallControlTerminal.
 * <p>
 * The methods added allow any Terminal to manage the association with
 * an ACDAddress in order to accept calls coming to the ACDAddress.
 * <p>
 * To observe state changes for the agent, an application must use
 * the methods Terminal.addObserver and Terminal.deleteObserver.
 */

public interface AgentTerminal extends CallControlTerminal {

  /**
   * This method either adds an Agent to this AgentTerminal in the
   * state specified or changes the state of a previously added Agent
   * or removes a previously added Agent.
   * <p>
   * If the state was set to LOG_IN, the Agent is added to this
   * AgentTerminal and the post and pre conditions are as follows:
   * <p>
   * The pre-condition predicates for this method are:
   * <br>
   * 1. (agentTerm.getProvider()).getState() == IN_SERVICE
   * <br>
   * 2. agent.setState (appropriate state)
   * <br>
   * 3. agent.agentAddress (an Address associated with the AgentTerminal)
   * <br>
   * 4. agent.set (any attribute that is needed by the implementation
   * to associate the Agent with the AgentTerminal in the specified
   * state).
   * <p>
   * The post-condition predicates for this method are:
   * <br>
   * 1. (agentTerm.getProvider()).getState() == IN_SERVICE
   * <br>
   * 2. agent.getState() == (state specified from the setState)
   * <p>
   * If the Agent has already been added, this method can be used to
   * change the Agent's state and the post and pre conditions are as
   * follows:
   * <p>
   * The pre-condition predicates for this method are:
   * <br>
   * 1. (agentTerm.getProvider()).getState() == IN_SERVICE
   * <br>
   * 2. (agentTerm.getAgents() union agent) == agent
   * <br>
   * 3. agent.setState (appropriate state)
   * <p>
   * The post-condition predicates for this method are:
   * <br>
   * 1. (agentTerm.getProvider()).getState() == IN_SERVICE
   * <br>
   * 2. agent.getState() == (state specified from the setState)
   * <p>
   * If the state was set to LOG_OUT, the Agent is removed from this
   * AgentTerminal and the post and pre conditions are as follows:
   * <p>
   * The pre-condition predicates for this method are:
   * <br>
   * 1. (agentTerm.getProvider()).getState() == IN_SERVICE
   * <br>
   * 2. (agentTerm.getAgents() union agent) == agent
   * <p>
   * The post-condition predicates for this method are:
   * <br>
   * 1. (agentTerm.getProvider()).getState() == IN_SERVICE
   * <br>
   * 2. (agentTerm.getAgents() union agent) == nil
   * <p>
   * @param agents being added, changed or removed.
   * @exception PlatformException A platform-specific exception occurred.
   */
  public void setAgents(Agent[] agents)
        throws PlatformException;

   /**
    * This returns one or more Agent objects added previously to this
    * AgentTerminal.
    * <p>
    * If an Agent has been removed from an AgentTerminal, no Agent
    * object will be returned to represent that.
    * <p>
    * @return A list of Agents associated with this Terminal.
    * @exception PlatformException An platform-specific exception occurred.
    */
   public Agent[] getAgents()
        throws PlatformException;
}
