/*
#pragma ident "@(#)CallCenterAddress.java	1.8      97/02/03     SMI"

 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcenter;
import  java.telephony.callcontrol.CallControlAddress;
import  java.telephony.*;

/**
 * The CallCenterAddress interface models call center addresses like
 * ACD groups and ACD Managers.
 * <p>
 * ACDAddress which models an ACD group, extends the CallcenterAddress.
 * <br>
 * ACDMangerAddress which models an ACD Manager, extends the CallcenterAddress.
 * <p>
 * This interface augments the core Address class to add a CallObserver.
 * The CallObserver reports all Call-related state changes as events as
 * well as all types of connection-related state changes as events for those
 * Connections and TerminalConnections associated with the Call.
 * The Call object will report events to this CallObserver object
 * only after the Call has involved Address. Once the Call has involved
 * this Address, the events will be reported on the CallObserver.
 */

public interface CallCenterAddress extends Address {

  /**
   * Adds a call observer to this CallCenterAddress. This differs from the
   * <EM>Address.addCallObserver()</EM> method in that is takes a boolean
   * argument. If true, the CallObserver will remain on the Call object
   * for the lifetime of the Call. If false, the CallObserver will remain on
   * the Call object only during the time when this Address is part of the
   * telephone Call. Therefore, addCallObserver(false) in equivalent to that
   * method found in the core package.
   * <p>
   * If an instance of the CallObserver has already been added to an Address,
   * repeated attempts to add the same CallObserver will silently fail. That
   * is, multiple instances of the same observer will not be added nor will
   * an exception be thrown.
   * <p>
   * There are no pre-conditions for this method.
   * <p>
   * The post-condition predicates for this method are:
   * <OL>
   * <LI>observer is an element of address.getCallObservers()
   * </OL>
   * <p>
   * @param observer The call observer being added.
   * @param remain If true, the observer remains on the Call for the lifetime
   * of the Call. If false, the observer remains on the Call so long as this
   * Address is part of the Call.
   * @exception ResourceUnavailableException The resource limit for the
   * numbers of observers has been exceeded.
   * @exception PlatformException A platform-specific exception occurred.
   */
  public void addCallObserver(CallObserver observer, boolean remain)
    throws ResourceUnavailableException, PlatformException;
}
