/**
#pragma ident "@(#)CallCenterTrunk.java	1.1      97/02/06     SMI"

 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcenter;
import  java.telephony.*;


/**
 * The CallCenterTrunk class represents a Trunk interface on a switch.
 * <p>
 * The first attribute is it "name". The Trunk's name identifies which
 * Trunk interface in the Provider is being used.
 * <p>
 * The second attribute of a Trunk is its "interface type". The type
 * indicates whether the Trunk is an Incoming, Outgoing or Unknown
 * type of interface.
 */

public class CallCenterTrunk {

  private String name;
  private int    type;

  /**
   * Trunk type: The Trunk Interface is incoming.
   */
  public final static int INCOMING_TRUNK     = 0x1;

  /**
   * Trunk type: The Trunk interface is outgoing.
   */
  public final static int OUTGOING_TRUNK     = 0x2;

  /**
   * Trunk type: The Trunk interface is unknown.
   */
  public final static int UNKNOWN_TRUNK     = 0x3;


  /**
   * This constructor is the default constructor, which only takes the
   * name to apply to this Trunk. The Trunk type is unknown.
   */
  public void CallCenterTrunk(String name) {
    this.name        = name;
    type             = UNKNOWN_TRUNK;
  }


  /**
   * This constructor takes the address to apply this trunk
   * and the type of trunk.
   */
  public void CallCenterTrunk(String name, int type) {
    this.name        = name;
    this.type        = type;
  }

  /**
   * Returns the Trunk's name.
   * <p>
   * @return The name of this trunk.
   */
  public String getName() {
    return this.name;
  }


  /**
   * Returns the type of trunk, either unknown, incoming or
   * outgoing.
   * <p>
   * @return The type of trunk.
   */
  public int getType() {
    return this.type;
  }
}

