/*
#pragma ident "@(#)RouteAddress.java	1.7      97/01/23     SMI"

 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcenter;
import  java.telephony.callcontrol.CallControlAddress;
import java.telephony.PlatformException;

/**
 * The RouteAddress interface augments the core Address class to add
 * methods to allow applications to register to route calls for a
 * specific Address. Such Addresses are typically logical PBX extension,
 * so it is being modeled by an extended Address.
 * <p>
 * An application can register to route calls for all extensions, this
 * is supported by invoking registration methods on a RouteAddress created
 * with a special valid Address, ALL_ROUTE_ADDRESS.
 */

public interface RouteAddress {

    /**
     * When an application registers to route calls for a RouteAddress
     * created with this special Address, the application is implying
     * that it wants to route calls for all Addresses in the Provider's
     * domain.
     */
    public static final String ALL_ROUTE_ADDRESS = "AllRouteAddress";

    /**
     * An application uses this method to register to route calls
     * for this Address.
     * The RouteCallback, passed in as a parameter, is called back
     * when the provider wants the application to route a call.
     * <p>
     * A Provider may support multiple registrations. Once the limit
     * on number of registrations is reached an exception will be
     * thrown.
     */
    public void registerRouteCallback(RouteCallback routeCallback)
		throws PlatformException;

    /**
     * An application uses this method to cancel a previous
     * registration to route calls for this Address.
     */
    public void cancelRouteCallback(RouteCallback routeCallback)
		throws PlatformException;

    /**
     * An application uses this method to get all registrations
     * to route calls for this Address.
     */
    public RouteCallback[] getRouteCallback()
		throws PlatformException;

    /**
     * An application uses this method to get all RouteSessions
     * active for this RouteAddress.
     */
    public RouteSession[] getActiveRouteSessions()
		throws PlatformException;

}
