/*
#pragma ident "@(#)RouteCallback.java	1.7      97/02/04     SMI"

 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcenter;
import  java.telephony.callcenter.events.*;

/**
 * The RouteCallback interface provides a mechanism to handle
 * routing events. The application implements the RouteCallback
 * interface which is called back when the provider wants the
 * application to route a call.
 */

public interface RouteCallback {


    /**
     * The routeEvent method is called by the provider
     * when it wants the application to route a call.
     * <br>
     * This corresponds to the RouteSession object
     * transitioning to the ROUTE state.
     */
    public abstract void routeEvent(RouteEvent event);

    /**
     * The reRouteEvent method is called by the provider
     * when it wants the application to select another
     * destination for the call.
     * <br>
     * This corresponds to the RouteSession object
     * transitioning to the RE_ROUTE state.
     */
    public abstract void reRouteEvent(RouteSessionEvent event);

    /**
     * The routeUsedEvent method is called by the provider
     * to inform the application of the actual destination
     * of a call, that the application helped to route.
     * <br>
     * This corresponds to the RouteSession object
     * transitioning to the ROUTE_USED state.
     */
    public abstract void routeUsedEvent(RouteUsedEvent event);

    /**
     * The routeEndEvent method is called by the provider
     * to inform the application of the termination of a
     * RouteSession.
     * <br>
     * This corresponds to the RouteSession object
     * transitioning to the ROUTE_END state.
     */
    public abstract void routeEndEvent(RouteEndEvent event);

    /**
     * The routeCallbackEndedEvent method is called by the
     * provider to inform the application of the termination
     * of a previous registration by the application to route
     * calls for a RouteAddress.
     * <br>
     * This corresponds to the RouteSession object
     * transitioning to the ROUTE_CALLBACK_ENDED state.
     */
    public abstract void routeCallbackEndedEvent(RouteCallbackEndedEvent event);

}
