/*
#pragma ident "@(#)RouteSession.java	1.8      97/02/04     SMI"

 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcenter;
import java.telephony.PlatformException;

/**
 * The RouteSession interface represents an outstanding route request.
 */

public interface RouteSession {

/**
 * The following define states that the RouteSession object
 * can be in.
 */
/**
 * The RouteSession object transitions to the ROUTE state when
 * the provider requests the application to route a call.
 */
public static final int ROUTE = 1;

/**
 * The RouteSession object transitions to the ROUTE_USED state
 * when the provider informs the application of the destination
 * of a call the application helped to route.
 */
public static final int ROUTE_USED = 2;

/**
 * The RouteSession object transitions to the ROUTE_END state
 * when the provider informs the application of termination
 * of a RouteSession.
 */
public static final int ROUTE_END = 3;

/**
 * The RouteSession object transitions to the RE_ROUTE state when
 * the provider requests the application to select another route
 * for a call.
 */
public static final int RE_ROUTE = 4;

/**
 * The RouteSession object transitions to the ROUTE_CALLBACK_ENDED
 * state when the provider informs the application of the
 * termination of a previous registration of a route callback.
 */
public static final int ROUTE_CALLBACK_ENDED = 5;

/**
 * The following define cause codes that may be returned by events.
 */
/**
 * Cause code indicating no error.
 */
public static final int CAUSE_NO_ERROR = 100;

/**
 * Cause code indicating a routing timer has expired.
 */
public static final int CAUSE_ROUTING_TIMER_EXPIRED = 101;

/**
 * Cause code indicating that the provider is ending the route
 * session because the application included a parameter in the
 * routeSelect() that the provider does not support.
 */
public static final int CAUSE_PARAMETER_NOT_SUPPORTED = 102;

/**
 * Cause code indicating that the provider is ending the route
 * session because the application included an invalid destination
 * in the routeSelect().
 */
public static final int CAUSE_INVALID_DESTINATION = 103;

/**
 * Cause code indicating that the provider is ending the route
 * session because the Connection state is incompatible with the
 * RouteSession.
 */
public static final int CAUSE_STATE_INCOMPATIBLE = 104;

/**
 * Cause code indicating that the provider is ending the route
 * session because some unspecified erroroccurred.
 */
public static final int CAUSE_UNSPECIFIED_ERROR = 105;

/**
 * This returns the RouteAddress that the application has
 * registered to route calls for.
 */
public RouteAddress getRouteAddress();

/**
 * An application uses this method to send back a selected route.
 */
   public void selectRoute(String[] routeSelected)
		throws PlatformException;


/**
 * An application uses this method to end a route session.
 */
   public void endRoute(int errorValue)
		throws PlatformException;

/**
 * An application uses this method to get the state of a route
 * session.
 */
   public int getState()
		throws PlatformException;

/**
 * An application uses this method to get the cause associated
 * with the state of the route session.
 */
   public int getCause()
		throws PlatformException;

}
