/*
 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcontrol.capabilities;
import  java.telephony.capabilities.AddressCapabilities;

/**
 * The CallControlAddressCapabilities interface extends the AddressCapabilities
 * interface. This interface provides methods to reflect the capabilities
 * of the CallControlAddress interface methods. Applications query the object
 * returned from the getAddressCapabilities() methods to see whether it
 * implements this interface for both the static and dynamic capabilities for
 * the CallControlAddress object.
 * <p>
 * @see java.telephony.capabilities.AddressCapabilities
 */

public interface CallControlAddressCapabilities extends AddressCapabilities {


  /**
   * Returns true if the application can invoke the
   * CallControlAddress.setForwarding() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlAddress.setForwarding() method, false otherwise.
   */
  public boolean canSetForwarding();


  /**
   * Returns true if the application can invoke the
   * CallControlAddress.getForwarding() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlAddress.getForwarding() method, false otherwise.
   */
  public boolean canGetForwarding();


  /**
   * Returns true if the application can invoke the
   * CallControlAddress.cancelForwarding() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlAddress.cancelForwarding() method, false otherwise.
   */
  public boolean canCancelForwarding();


  /**
   * Returns true if the application can invoke the
   * CallControlAddress.getDoNotDisturb() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlAddress.getDoNotDisturb() method, false otherwise.
   */
  public boolean canGetDoNotDisturb();


  /**
   * Returns true if the application can invoke the
   * CallControlAddress.setDoNotDisturb() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlAddress.setDoNotDisturb() method, false otherwise.
   */
  public boolean canSetDoNotDisturb();


  /**
   * Returns true if the application can invoke the
   * CallControlAddress.getMessageWaiting() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlAddress.getMessageWaiting() method, false otherwise.
   */
  public boolean canGetMessageWaiting();


  /**
   * Returns true if the application can invoke the
   * CallControlAddress.setMessageWaiting() method. Returns false
   * otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlAddress.setMessageWaiting() method, false otherwise.
   */
  public boolean canSetMessageWaiting();
}
