/*
 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcontrol.capabilities;
import  java.telephony.capabilities.CallCapabilities;

/**
 * The CallControlCallCapabilities interface extends the CallCapabilities
 * interface. This interface provides methods to reflect the capabilities
 * of the CallControlCall interface methods. Applications query the object
 * returned from the getCallCapabilities() methods to see whether it implements
 * this interface for both the static and dynamic capabilities for the
 * CallControlCall object.
 * <p>
 * @see java.telephony.capabilities.CallCapabilities
 */

public interface CallControlCallCapabilities extends CallCapabilities {

  /**
   * Returns true if the application can invoke the CallControlCall.drop()
   * method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the CallControlCall.drop()
   * method, false otherwise.
   */
  public boolean canDrop();

  /*
   * Returns true if the application can invoke the 
   * CallControlCall.offHook() method, returns false otherwise.
   * <p>
   * @return true if the application can invoke the 
   * CallControlCall.offHook() method, returns false otherwise.
   */
  public boolean canOffHook();

  /*
   * Returns true if the application can invoke the 
   * CallControlCall.setConferenceController() method, returns false otherwise.
   * <p>
   * @return true if the application can invoke the 
   * CallControlCall.setConferenceController() method, returns false otherwise.
   */
  public boolean canSetConferenceController();
 
  /*
   * Returns true if the application can invoke the 
   * CallControlCall.setTransferController() method, returns false otherwise.
   * <p>
   * @return true if the application can invoke the 
   * CallControlCall.setTransferController() method, returns false otherwise.
   */
  public boolean canSetTransferController();

  /**
   * Returns true if the application can invoke the
   * CallControlCall.setTransferEnable() method. Returns false otherwise. The
   * outcome of this capability is independent of whether applications can
   * invoke the transfer() method. Applications both may not be able to turn
   * transfering off it is on, and may not be able to turn transfering on if
   * it is off.
   * <p>
   * @return True if the application can invoke the
   * CallControlCall.setTransferEnable() method, false otherwise.
   */
  public boolean canSetTransferEnable();


  /**
   * Returns true if the application can invoke the
   * CallControlCall.canSetConferenceEnable() method. Returns false otherwise.
   * The outcome of this capability is independent of whether applications
   * can invoke the conference() method. Applications both may not be able
   * to turn conferencing off if it is on, and may not be able to turn
   * conferencing on if it is off.
   * <p>
   * @return True if the application can invoke the
   * CallControlCall.setConferenceEnable() method, false otherwise.
   */
  public boolean canSetConferenceEnable();


  /**
   * Returns true if the application can invoke the CallControlCall.transfer()
   * method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the CallControlCall.transfer()
   * method, false otherwise.
   */
  public boolean canTransfer();


  /**
   * Returns true if the application can invoke the
   * CallControlCall.conference() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlCall.conference() method, false otherwise.
   */
  public boolean canConference();


  /**
   * Returns true if the application can invoke the CallControlCall.addParty()
   * method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the CallControlCall.addParty()
   * method, false otherwise.
   */
  public boolean canAddParty();


  /**
   * Returns true if the application can invoke the CallControlCall.consult()
   * method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the CallControlCall.consult()
   * method, false otherwise.
   */
  public boolean canConsult();
}
