/*
 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcontrol.capabilities;
import  java.telephony.capabilities.ConnectionCapabilities;

/**
 * The CallControlConnectionCapabilities interface extends the
 * ConnectionCapabilities interface. This interface provides methods to
 * reflect the capabilities of the CallControlConnection interface methods.
 * Applications query the object returned from the getConnectionCapabilities()
 * methods to see whether it implements this interface for both the static and
 * dynamic capabilities for the CallControlConnection object.
 * <p>
 * @see java.telephony.capabilities.ConnectionCapabilities
 */

public interface CallControlConnectionCapabilities extends ConnectionCapabilities {

  /**
   * Returns true if the application can invoke the
   * CallControlConnection.redirect() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlConnection.redirect() method, false otherwise.
   */
  public boolean canRedirect();


  /**
   * Returns true if the application can invoke the
   * CallControlConnection.addToAddress() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlConnection.addToAddress() method, false otherwise.
   */
  public boolean canAddToAddress();


  /**
   * Returns true if the application can invoke the
   * CallControlConnection.accept() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlConnection.accept() method, false otherwise.
   */
  public boolean canAccept();


  /**
   * Returns true if the application can invoke the
   * CallControlConnection.reject() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlConnection.reject() method, false otherwise.
   */
  public boolean canReject();


  /**
   * Returns true if the application can invoke the
   * CallControlConnection.park() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlConnection.park() method, false otherwise.
   */
  public boolean canPark();
}
