/*
 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcontrol.capabilities;
import  java.telephony.capabilities.TerminalCapabilities;

/**
 * The CallControlTerminalCapabilities interface extends the
 * TerminalCapabilities interface. This interface provides methods to reflect
 * the capabilities of the CallControlTerminal interface methods. Applications
 * query the object returned from the getTerminalCapabilities() methods to see
 * whether it implements this interface for both the static and dynamic
 * capabilities for the CallControlTerminal object.
 * <p>
 * @see java.telephony.capabilities.TerminalCapabilities
 */

public interface CallControlTerminalCapabilities extends TerminalCapabilities {

  /**
   * Returns true if the application can invoke the
   * CallControlTerminal.getDoNotDisturb() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlTerminal.getDoNotDisturb() method, false otherwise.
   */
  public boolean canGetDoNotDisturb();


  /**
   * Returns true if the application can invoke the
   * CallControlTerminal.setDoNotDisturb() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlTerminal.setDoNotDisturb() method, false otherwise.
   */
  public boolean canSetDoNotDisturb();


  /**
   * Returns true if the application can invoke the
   * CallControlTerminal.pickup() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlTerminal.pickup() method, false otherwise.
   */
  public boolean canPickup();


  /**
   * Returns true if the application can invoke the
   * CallControlTerminal.pickupFromGroup() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlTerminal.pickupFromGroup() method, false otherwise.
   */
  public boolean canPickupFromGroup();
}
