/*
 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcontrol.capabilities;
import  java.telephony.capabilities.TerminalConnectionCapabilities;

/**
 * The CallControlTerminalConnectionCapabilities interface extends the
 * TerminalConnectionCapabilities interface. This interface provides methods
 * to reflect the capabilities of the CallControlTerminalConnection interface
 * methods. Applications query the object returned from the
 * getTerminalConnectionCapabilities() methods to see whether it implements
 * this interface for both the static and dynamic capabilities for the
 * CallControlTerminalConnection object.
 * <p>
 * @see java.telephony.capabilities.TerminalConnectionCapabilities
 */

public interface CallControlTerminalConnectionCapabilities extends TerminalConnectionCapabilities {

  /**
   * Returns true if the application can invoke the
   * CallControlTerminalConnection.hold() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlTerminalConnection.hold() method, false otherwise.
   */
  public boolean canHold();


  /**
   * Returns true if the application can invoke the
   * CallControlTerminalConnection.unhold() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlTerminalConnection.unhold() method, false otherwise.
   */
  public boolean canUnhold();


  /**
   * Returns true if the application can invoke the
   * CallControlTerminalConnection.join() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlTerminalConnection.join() method, false otherwise.
   */
  public boolean canJoin();


  /**
   * Returns true if the application can invoke the
   * CallControlTerminalConnection.leave() method. Returns false otherwise.
   * <p>
   * @return True if the application can invoke the
   * CallControlTerminalConnection.leave() method, false otherwise.
   */
  public boolean canLeave();
}
