/*
#pragma ident "@(#)CallCtlEv.java	1.5      96/11/03     SMI"

 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.callcontrol.events;
import  java.telephony.events.Ev;

/**
 * The CallCtlEv is the base event for all events in the CallControl
 * package. Each event in this package must extend this interface. This
 * interface is not meant to be a public interface, it is just a building
 * block for other event interfaces.
 * <p>
 * The CallCtlEv interface contains getCallControlCause(), which returns
 * the reason for the event.
 */

public interface CallCtlEv extends Ev {

  /**
   * Cause code indicating a call was put on hold and another
   * retrieved in an atomic operation, typical on single line
   * phones.
   */
  public static final int CAUSE_ALTERNATE = 202;

  /**
   * Cause code indicating a call encountered a busy endpoint.
   */
  public static final int CAUSE_BUSY = 203;

  /**
   * Cause code indicating event is related to the CallBack
   * feature.
   */
  public static final int CAUSE_CALL_BACK = 204;

  /**
   * Cause code indicating call was not answered before a
   * timer elapsed.
   */
  public static final int CAUSE_CALL_NOT_ANSWERED = 205;

  /**
   * Cause code indicating call was redirected by a Call
   * Pickup feature.
   */
  public static final int CAUSE_CALL_PICKUP = 206;

  /**
   * Cause code indicating event is related to the Conference
   * feature.
   */
  public static final int CAUSE_CONFERENCE = 207;

  /**
   * Cause code indicating event is related to the Do Not Disturb
   * feature.
   */
  public static final int CAUSE_DO_NOT_DISTURB = 208;

  /**
   * Cause code indicating event is related to the Park feature.
   */
  public static final int CAUSE_PARK = 209;

  /**
   * Cause code indicating event is related to the Redirected feature.
   */
  public static final int CAUSE_REDIRECTED = 210;

  /**
   * Cause code indicating call encountered reorder tone
   */
    public static final int CAUSE_REORDER_TONE = 211;

  /**
   * Cause code indicating event is related to the Tranfer
   * feature.
   */
    public static final int CAUSE_TRANSFER = 212;

  /**
   * Cause code indicating call encountered a busy trunk
   */
    public static final int CAUSE_TRUNKS_BUSY = 213;

  /**
   * Cause code indicating event is related to the Unhold
   * feature.
   */
    public static final int CAUSE_UNHOLD = 214;

  /**
   * We also need cause codes for the different kinds of forwarding
   */

  /**
   * Returns the call control and core causes associated with this event.
   * Every event has a cause. The various cause values are defined as public
   * static final variablies in this interface, with the exception of
   * CAUSE_NORMAL and CAUSE_UNKNOWN, which are defined in the core.
   *
   * <p>
   * @returns The cause of the event.
   */
  public int getCallControlCause();

}
