/*
 * Copyright (c) 1997.  Sun Microsystems.  All rights reserved.
 * 
 * Use search() to compare values against values contained in entry
 * "cn=Barbara Jensen, ou=Product Development, o=Ace Industry, c=US".
 * We test to see if (1) the value "person" is one of the values in the
 * objectclass attribute (it is), and if (2) the value "xyzzy" is in the
 * objectlass attribute (it isn't, or at least, it shouldn't be).
 *
 * [equivalent to compare.c in Netscape SDK]
 *
 */

import java.util.Properties;
import java.util.Enumeration;
 
import java.naming.*;
import java.naming.directory.*;

class Compare {

public static void main(String[] args) {

    Properties env = new Properties();
    /*
     * Specify the initial context implementation to use.
     * This could also be set by using the -D option to the java program.
     * For example,
     *   java -Djndi.initialContextFactory=sun.jndi.ldap.LdapCtxFactory Compare
     */
    env.put("jndi.initialContextFactory", Env.INITCTX);

    /* Specify host and port to use for directory service */
    env.put("jndi.service.url", Env.MY_SERVICE);

    /* get a handle to an Initial DSContext */
    DSContext ctx = new InitialDSContext(env);

    SearchConstraints constraints = new SearchConstraints();
    constraints.setSearchScope(SearchConstraints.OBJECT_SCOPE);
    constraints.setReturningAttributes(new String[0]);  // do not return any attrs

    try {
        SearchEnumeration results = 
            ctx.search(Env.ENTRYDN, "objectclass=person", constraints);

        if (results != null && results.hasMoreElements()) {
            System.out.println(
		"The value \"person\" is contained in the objectclass attribute.");
        } else {
            System.out.println(
		"The value \"person\" is not contained in the objectclass attribute." );
        }
    } catch (NamingException e) {
        System.err.println("Comparison of value person failed");
    }

    try {
        SearchEnumeration results = 
            ctx.search(Env.ENTRYDN, "objectclass=xyzzy", constraints);
        
        if (results != null && results.hasMoreElements()) {
            System.out.println(
		"The value \"xyzzy\" is contained in the objectclass attribute.");
        } else {
            System.out.println(
		"The value \"xyzzy\" is not contained in the objectclass attribute." );
        }
    } catch (NamingException e) {
        System.err.println("Comparison of value xyzzy failed");
    }
}
}
