/*
 * Copyright (c) 1997.  Sun Microsystems.  All rights reserved.
 *
 * Retrieve several attributes of a particular entry.
 *
 * [equivalent to getattrs.c in Netscape SDK]
 */

import java.util.Properties;
import java.util.Enumeration;
 
import java.naming.*;
import java.naming.directory.*;

class Getattrs {

public static void main(String[] args) {

    Properties env = new Properties();
    /*
     * Specify the initial context implementation to use.
     * This could also be set by using the -D option to the java program.
     * For example,
     *   java -Djndi.initialContextFactory=sun.jndi.ldap.LdapCtxFactory Getattrs
     */
    env.put("jndi.initialContextFactory", Env.INITCTX);

    /* Specify host and port to use for directory service */
    env.put("jndi.service.url", Env.MY_SERVICE);

    try {
        /* get a handle to an Initial DSContext */
        DSContext ctx = new InitialDSContext(env);

        String[] attrs = new String[4];
        attrs[ 0 ] = "cn";              /* Get canonical name(s) (full name) */
        attrs[ 1 ] = "sn";              /* Get surname(s) (last name) */
        attrs[ 2 ] = "mail";            /* Get email address(es) */
        attrs[ 3 ] = "telephonenumber"; /* Get telephone number(s) */

        AttributeSet result = ctx.getAttributes(Env.ENTRYDN, attrs);

        if (result == null) {
            System.out.println(Env.ENTRYDN + "has none of the specified attributes");
        } else {
            /* print it out */
            Attribute attr = result.get("cn");
            if (attr != null) {
                System.out.println("Full name:" );
                for (Enumeration vals = attr.getValues();
                     vals.hasMoreElements();
                     System.out.println("\t" + vals.nextElement()))
                    ;
            }

            attr = result.get("sn");
            if (attr != null) {
                System.out.println("Last name (surname):" );
                for (Enumeration vals = attr.getValues();
                     vals.hasMoreElements();
                     System.out.println("\t" + vals.nextElement()))
                    ;
            }

            attr = result.get("mail");
            if (attr != null) {
                System.out.println("Email address:" );
                for (Enumeration vals = attr.getValues();
                     vals.hasMoreElements();
                     System.out.println("\t" + vals.nextElement()))
                    ;
            }
            attr = result.get("telephonenumber");
            if (attr != null) {
                System.out.println("Telephone number:" );
                for (Enumeration vals = attr.getValues();
                     vals.hasMoreElements();
                     System.out.println("\t" + vals.nextElement()))
                    ;
            }
        }
    } catch (NamingException e) {
        System.err.println("Rdentry example failed");
        e.printStackTrace();
    }
}
}

