/*
 * Copyright (c) 1997.  Sun Microsystems.  All rights reserved.
 * 
 * Modify an entry:
 *  - replace any existing values in the "mail" attribute with "babs@ace.com"
 *  - add a new value to the "description" attribute
 *
 * [equivalent to modattrs.c in Netscape SDK]
 */

import java.util.Properties;
import java.util.Date;
 
import java.naming.*;
import java.naming.directory.*;

class Modattrs {

public static void main(String[] args) {

    Properties env = new Properties();
    /*
     * Specify the initial context implementation to use.
     * This could also be set by using the -D option to the java program.
     * For example,
     *   java -Djndi.initialContextFactory=sun.jndi.ldap.LdapCtxFactory Modattrs
     */
    env.put("jndi.initialContextFactory", Env.INITCTX);

    /* specify host and port to use for directory service */
    env.put("jndi.service.url", Env.MY_SERVICE);

    /* specify authentication information */
    env.put("jndi.security.principal", Env.MGR_DN);
    env.put("jndi.security.credentials", Env.MGR_PW);

    try {
        /* get a handle to an Initial DSContext */
        DSContext ctx = new InitialDSContext(env);

        /* construct the list of modifications to make */
        ModificationEnumeration mods = new ModificationEnumeration();

        Attribute mod0 = new Attribute("mail", "babs@eng");
	// Update mail attribute
        mods.append(DSContext.REPLACE_ATTRIBUTE, mod0);

	// Add another value to description attribute
        Attribute mod1 = 
            new Attribute("description", 
                          "This entry was modified with the Modattrs program on " +
                          (new Date()).toString());
        mods.append(DSContext.ADD_ATTRIBUTE, mod1);

	 /* Delete the description attribute altogether */
	/*
        Attribute mod1 =  new Attribute("description");
        mods.append(DSContext.DELETE_ATTRIBUTE, mod1);
	*/

        /* make the change */
        ctx.modifyAttributes(Env.ENTRYDN, mods);
        System.out.println( "modification was successful" );

    } catch (NamingException e) {
        System.err.println("modification failed" + e);
    }
}
}

