/*
 * Copyright (c) 1997.  Sun Microsystems. All rights reserved.
 * 
 * Search the directory for all people whose surname (last name) is
 * "Jensen".  Since the "sn" attribute is a caseignorestring (cis), case
 * is not significant when searching.
 *
 * Catch referrals and ask for confirmation to proceed.
 * 
 * To exercise the referral handler in this program ensure that
 * the target directory service returns a referral for the name
 * specificed by Env.MY_SEARCHBASE.
 */

import java.util.Properties;
import java.util.Enumeration;
import java.io.*;

import java.naming.*;
import java.naming.directory.*;

class RefSearch {

public static void main(String[] args) throws IOException {

    Properties env = new Properties();
    /*
     * Specify the initial context implementation to use.
     * This could also be set by using the -D option to the java program.
     * For example,
     *  java -Djndi.initialContextFactory=sun.jndi.ldap.LdapCtxFactory RefSearch
     */
    env.put("jndi.initialContextFactory", Env.INITCTX);

    /* Specify host and port to use for directory service */
    env.put("jndi.service.url", Env.MY_SERVICE);

    /* do not automatically follow referrals */
    env.put("jndi.service.followReferrals", "false");

    try {
        /* get a handle to an Initial DSContext */
        DSContext ctx = new InitialDSContext(env);

        /* specify search constraints to search subtree */
        SearchConstraints constraints = new SearchConstraints();
        constraints.setSearchScope(SearchConstraints.SUBTREE_SCOPE);

        /* search for all entries with surname of Jensen */
        SearchEnumeration results;

	while (true) {
	    try {
        	results =
		    ctx.search(Env.MY_SEARCHBASE, Env.MY_FILTER, constraints);
		/* for each entry print out name + all attrs and values */
		while (results != null && results.hasMore()) {
		    SearchResult si = results.next();

		    /* print its name */
		    System.out.println("name: " + si.getName());

		    AttributeSet attrs = si.getAttributes();
		    if (attrs == null) {
			System.out.println("No attributes");
		    } else {
			/* print each attribute */
			for (AttributeEnumeration ae = attrs.getAttributes();
			    ae.hasMoreElements();) {
			    Attribute attr = ae.next();
			    String attrId = attr.getAttributeId();

			    /* print each value */
			    for (Enumeration vals = attr.getValues();
				vals.hasMoreElements();
				System.out.println(attrId + ": " +
				    vals.nextElement()))
				;
			}
		    }
		    System.out.println();
		}

		break;

	    } catch (ReferralException e) {

		if (! followReferrals(e))
		    return;

		/* point to the new context */
		ctx = (DSContext) e.getReferralContext();
	    }
	}
    } catch (NamingException e) {
        System.err.println("Search example failed");
        e.printStackTrace();
    }
}

private static boolean followReferrals(ReferralException e) throws IOException {
    byte[] reply = new byte[2];

    System.out.println("Received the following referral(s):");
    System.out.println(e.toString());
    System.out.print("Follow the referral(s)? [y/n] ");
    System.in.read(reply);

    return (reply[0] != 'n');
}
}
