/*
 * Copyright (c) 1997.  Sun Microsystems. All rights reserved.
 * 
 * Search the directory for all people whose surname (last name) is
 * "Jensen".  Since the "sn" attribute is a caseignorestring (cis), case
 * is not significant when searching.
 *
 * [equivalent to search.c in Netscape's SDK.]
 *
 */

import java.util.Properties;
import java.util.Enumeration;

import java.naming.*;
import java.naming.directory.*;

class Search {

public static void main(String[] args) {

    Properties env = new Properties();
    /*
     * Specify the initial context implementation to use.
     * This could also be set by using the -D option to the java program.
     * For example,
     *   java -Djndi.initialContextFactory=sun.jndi.ldap.LdapCtxFactory Search
     */
    env.put("jndi.initialContextFactory", Env.INITCTX);

    /* Specify host and port to use for directory service */
    env.put("jndi.service.url", Env.MY_SERVICE);

    try {
        /* get a handle to an Initial DSContext */
        DSContext ctx = new InitialDSContext(env);

        /* specify search constraints to search subtree */
        SearchConstraints constraints = new SearchConstraints();
        constraints.setSearchScope(SearchConstraints.SUBTREE_SCOPE);

        /* search for all entries with surname of Jensen */
        SearchEnumeration results
            = ctx.search(Env.MY_SEARCHBASE, Env.MY_FILTER, constraints);

        /* for each entry print out name + all attrs and values */
        while (results != null && results.hasMoreElements()) {
            SearchResult si = results.next();

            /* print its name */
            System.out.println("name: " + si.getName());

            AttributeSet attrs = si.getAttributes();
            if (attrs == null) {
                System.out.println("No attributes");
            } else {
                /* print each attribute */
                for (AttributeEnumeration ae = attrs.getAttributes();
                     ae.hasMoreElements();) {
                    Attribute attr = ae.next();
                    String attrId = attr.getAttributeId();

                    /* print each value */
                    for (Enumeration vals = attr.getValues();
                         vals.hasMoreElements();
                         System.out.println(attrId + ": " + vals.nextElement()))
                            ;
                }
            }
	    System.out.println();
        }
    } catch (NamingException e) {
        System.err.println("Search example failed");
        e.printStackTrace();
    }
}
}
