/*
#pragma ident "@(#)PrivateData.java	1.7      97/01/22     SMI"

 * Copyright (c) 1996 Sun Microsystems, Inc. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and without
 * fee is hereby granted provided that this copyright notice
 * appears in all copies. Please refer to the file "copyright.html"
 * for further important copyright and licensing information.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package java.telephony.privatedata;
import java.telephony.Call;

/**
 * The Private Data interface for all JTT objects. Any implementation that
 * wants to implement private data should implement this interface on a
 * per-object basis. 
 */

public interface PrivateData {

  /**
   * Associates some platform-specific data with the next method that is
   * invoked on the object for which this PrivateData interface is implemented.
   * The format of this data and the manner in which it modifies the method
   * invocation is platform-dependent. This data applies to the next method
   * ONLY and does not affect any future method invocations.
   * <p>
   * @param data The platform-dependent data.
   * @exception Exception Some exception thrown.
   */
  public void setPrivateData(Object data)
    throws Exception;


  /**
   * Immediately performs some platform-specific action. The effect of this 
   * methods invocation is immediate and does not directly relate to any 
   * future object method invocations. The action taken upon receipt of this
   * data is platform-dependent as is the format of the data itself.
   * <p>
   * @param data The platform-dependent data.
   * @exception Exception Some exception thrown.
   */
  public void sendPrivateData(Object data)
    throws Exception;
}
