/*
 * @(#)ComboBoxPanel.java	1.10 97/08/26
 * 
 * Copyright (c) 1997 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 * 
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 * 
 */

import com.sun.java.swing.*;
import com.sun.java.swing.event.*;
import com.sun.java.swing.text.*;
import com.sun.java.swing.border.*;
import com.sun.java.swing.basic.BasicComboBoxUI;
import java.awt.*;
import java.awt.event.*;
import java.util.*;
import com.sun.java.swing.plaf.*;

/**
 * SwingSet panel for JComboBox
 *
 * @version 1.10 08/26/97
 * @author Arnaud Weber
 */
public class ComboBoxPanel extends JBufferedPane {
    // The Frame
    SwingSet swing;
    JComboBox  months;
    JComboBox  days;
    JComboBox  cb;
    JComboBox  cb1;
    JComboBox  custom;
    JComboBox  treeComboBox;

    DefaultListModel model = new DefaultListModel();

    public ComboBoxPanel(SwingSet swing) {
      JBorderedPane tp;
      this.swing = swing;
      this.setLayout(new BoxLayout(this,BoxLayout.Y_AXIS));
      setInsets(swing.insets5);
      
      this.add(Box.createRigidArea(new Dimension(1,50)));
      JBufferedPane panel = new JBufferedPane(false);
      panel.setLayout(new BoxLayout(panel,BoxLayout.X_AXIS));
      add(panel);
      // Classic combo box
      tp = new JBorderedPane();
      tp.setMaximumSize(new Dimension(Integer.MAX_VALUE,100));
      tp.setBorder(BorderFactory.createTitledBorder(tp, "Classic ComboBox"));
//      tp.setTitle("Classic ComboBox");
      tp.setLayout(new BoxLayout(tp,BoxLayout.X_AXIS));
      tp.add(Box.createRigidArea(new Dimension(5,1)));
      months = new JComboBox();
      months.setMaximumSize(new Dimension(Integer.MAX_VALUE,20));
      months.addPossibleValue("January");
      months.addPossibleValue("February");
      months.addPossibleValue("March");
      months.addPossibleValue("April");
      months.addPossibleValue("May");
      months.addPossibleValue("June");
      months.addPossibleValue("July");
      months.addPossibleValue("August");
      months.addPossibleValue("September");
      months.addPossibleValue("October");
      months.addPossibleValue("November");
      months.addPossibleValue("December");
      tp.add(months);
      tp.add(Box.createRigidArea(new Dimension(5,1)));
      days = new JComboBox();
      days.setMaximumSize(new Dimension(Integer.MAX_VALUE,20));
      days.addPossibleValue("Monday");
      days.addPossibleValue("Tuesday");
      days.addPossibleValue("Wednesday");
      days.addPossibleValue("Thursday");
      days.addPossibleValue("Friday");
      days.addPossibleValue("Saturday");
      days.addPossibleValue("Sunday");
      tp.add(days);
      tp.add(Box.createRigidArea(new Dimension(5,1)));
      panel.add(tp);

      // Editable combo box

      add(panel);
      tp = new JBorderedPane();
      tp.setMaximumSize(new Dimension(Integer.MAX_VALUE,100));
      tp.setBorder(BorderFactory.createTitledBorder(tp, "Editable ComboBox"));
//      tp.setTitle("Editable ComboBox");
      tp.setLayout(new BoxLayout(tp,BoxLayout.X_AXIS));
      tp.add(Box.createRigidArea(new Dimension(5,1)));
      cb = new JComboBox();
      cb.setEditable(true);
      cb.addPossibleValue("0");
      cb.addPossibleValue("10");
      cb.addPossibleValue("20");
      cb.addPossibleValue("30");
      cb.addPossibleValue("40");
      cb.addPossibleValue("50");
      cb.addPossibleValue("60");
      cb.addPossibleValue("70");
      cb.addPossibleValue("80");
      cb.addPossibleValue("90");
      cb.addPossibleValue("100");
      cb.addPossibleValue("More");
      cb.setCurrentValue("50");
      tp.add(cb);

      tp.add(Box.createRigidArea(new Dimension(5,1)));

      cb1 = new JComboBox();
      cb1.setEditable(true);
      cb1.addPossibleValue("0");
      cb1.addPossibleValue(".25");
      cb1.addPossibleValue(".5");
      cb1.addPossibleValue(".75");
      cb1.addPossibleValue("1.0");
      cb1.setCurrentValue(".5");
      tp.add(cb1);

      tp.add(Box.createRigidArea(new Dimension(5,1)));
      panel.add(tp);

      // Custom combobox
      panel = new JBufferedPane(false);
      panel.setLayout(new BoxLayout(panel,BoxLayout.X_AXIS));
      add(panel);
      tp = new JBorderedPane();
      tp.setMaximumSize(new Dimension(Integer.MAX_VALUE,200));
      tp.setBorder(BorderFactory.createTitledBorder(tp, "Custom ComboBox"));
//      tp.setTitle("Custom ComboBox");
      tp.setLayout(new BoxLayout(tp,BoxLayout.X_AXIS));
      tp.add(Box.createRigidArea(new Dimension(5,1)));
      custom = new JComboBox(new CustomComboBoxModel());
      custom.setRenderer(new TestCellRenderer(custom));
      custom.setCurrentValueFromIndex(0);
      custom.setMaximumRowCount(4);
      tp.add(custom);
      tp.add(Box.createRigidArea(new Dimension(5,1)));

      TreeNode swingNode = new TreeNode("Swing");
      TreeNode spec  = new TreeNode("spec");
      TreeNode api   = new TreeNode("api");

      swingNode.add(spec);
      swingNode.add(api);

      api.add(new TreeNode("JComponent"));
      api.add(new TreeNode("JTable"));
      api.add(new TreeNode("JTree"));
      api.add(new TreeNode("JComboBox"));
      api.add(new TreeNode("JTextComponent"));

      spec.add(new TreeNode("JComponent"));
      spec.add(new TreeNode("JTable"));
      spec.add(new TreeNode("JTree"));
      spec.add(new TreeNode("JComboBox"));
      spec.add(new TreeNode("JTextComponent"));
      
      treeComboBox = new TreeCombo(new DefaultTreeModel(swingNode));
      treeComboBox.setMaximumSize(new Dimension(Integer.MAX_VALUE,22));
      tp.add(treeComboBox);
      tp.add(Box.createRigidArea(new Dimension(5,1)));
      panel.add(tp);
    }

    class CustomComboBoxModel extends AbstractListModel implements ComboBoxModel {
      Object currentValue;
      ImageIcon images[];
      ImageIcon images_down[];      
      Hashtable cache[];

      public CustomComboBoxModel() {
	images = new ImageIcon[5];
	images_down = new ImageIcon[5];
	images[0] = new ImageIcon("images/list/a1.gif");
        images_down[0] = new ImageIcon("images/list/a1d.gif");
	images[1] = new ImageIcon("images/list/a2.gif");
        images_down[1] = new ImageIcon("images/list/a2d.gif");
	images[2] = new ImageIcon("images/list/a3.gif");
        images_down[2] = new ImageIcon("images/list/a3d.gif");
	images[3] = new ImageIcon("images/list/a4.gif");
        images_down[3] = new ImageIcon("images/list/a4d.gif");
	images[4] = new ImageIcon("images/list/a5.gif");
        images_down[4] = new ImageIcon("images/list/a5d.gif");
	cache = new Hashtable[getSize()];
      }

      public void setCurrentValue(Object anObject) {
	currentValue = anObject;
	notifyListDataListeners(new ListDataEvent(this,ListDataEvent.CONTENTS_CHANGED,-1,-1));
      }
      
      public Object getCurrentValue() {
	return currentValue;
      }

      public int getSize() {
	return 25;
      }

      public Object getElementAt(int index) {
	if(cache[index] != null)
	  return cache[index];
	else {
	  Hashtable result = new Hashtable();
	    if(index != 24) {
	      result.put("title","Hello I'm the choice " + index);
	      result.put("image",images[index % 5]);
	      result.put("Himage",images_down[index % 5]);
	    } else {
	      result.put("title","Hello I'm Duke");
	      result.put("image",swing.dukeSnooze);
	      result.put("Himage",swing.dukeWave);
	    }
	  cache[index] = result;
	  return result;
	}
      }
    }

    class TestCellRenderer extends JLabel implements ListCellRenderer   {
	JComboBox combobox;

      public TestCellRenderer(JComboBox x) {
        this.combobox = x;
      }

      public void configureListCellRenderer(Object value, int index) {
	boolean isSelected = (value == combobox.getCurrentValue());

	Hashtable h = (Hashtable) value;
	if(value == null) {
	  setText("");
	  setIcon(null);
	} else if(isSelected) {
	  setIcon((ImageIcon)h.get("Himage"));
	  setText((String)h.get("title"));
	} else {
	  setIcon((ImageIcon)h.get("image"));
	  setText((String)h.get("title"));
	}
      }

      public Component getListCellRendererComponent() {
	return this;
      }

      public Dimension getPreferredSize() {
	Dimension d = super.getPreferredSize();
	d.width += 30;
	return d;
      }
    }

    class BarRenderer extends JProgressBar implements Renderer {
      boolean isSelected=false;

      public BarRenderer() {
	setMinimum(0);
	setMaximum(100);
	setBorderPainted(false);
	setBackgroundPainted(false);
      }

      public void setValue(Object value,boolean isSelected) {
	double v = Double.valueOf((String)value).doubleValue();
	setValue((int)Math.rint(v * 100));
	this.isSelected = isSelected;
      }

      public void paint(Graphics g) {
	Rectangle r;
	Rectangle cr;
	Rectangle lb = new Rectangle(getSize());

	lb.x--;
	lb.width+=2;
	cr = g.getClipBounds();
	r = cr.intersection(lb);
	if(!r.isEmpty()) {
	  g.setColor(Color.white);	
	  g.fillRect(r.x,r.y,r.width,r.height);
	}

	if(isSelected)
	  setForeground(new Color(0,0,255));
	else
	  setForeground(new Color(0,0,100));
	super.paint(g);
      }

      public Component getComponent() {
	return this;
      }

      public Dimension getMinimumSize() {
	Dimension d = super.getMinimumSize();
	if(d.height < 20)
	  d.height = 20;
	return d;
      }

      public Dimension getPreferredSize() {
	Dimension d = super.getPreferredSize();
	if(d.height < 20)
	  d.height = 20;
	return d;
      }

      public Dimension getMaximumSize() {
	Dimension d = super.getMaximumSize();
	if(d.height < 20)
	  d.height = 20;
	return d;
     
      }
    }

    public void hideAllPopups() {
	months.getUI().hidePopup();
	days.getUI().hidePopup();
	cb.getUI().hidePopup();
	cb1.getUI().hidePopup();
	custom.getUI().hidePopup();
	treeComboBox.getUI().hidePopup();
    }

    class ProgressBarComboxUI extends BasicComboBoxUI {
        protected JListBox createListBox(ComboBoxModel m) {
            JListBox res = new JListBox(m);
            res.setSelectionPainted(false);
            return res;
        }
    }
}






