/*
 * @(#)InternalWindowPanel.java	1.12 97/08/31
 * Copyright (c) 1997 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 */

import com.sun.java.swing.*;
import com.sun.java.swing.border.*;

import java.awt.Panel;
import java.awt.Color;
import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.awt.Font;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Color;
import java.awt.Rectangle;
import java.awt.Container;

/*
 * @version 1.12 08/31/97
 * @author Dave Kloba
 */
public class InternalWindowPanel extends JBufferedPane implements ActionListener     {
    // Maker values
    JCheckBox closeBox;
    JCheckBox maxBox;
    JCheckBox iconBox;
    JCheckBox resizeBox;
    JTextField titleField;
    JTextField layerField;
    JButton closeAllButton;
    JButton makeButton;
    JLayeredPane lc;
    int makeCount = 0;
    JInternalFrame maker;

    public InternalWindowPanel()    {
        setLayout(new BorderLayout());
        lc = new JDesktopPane();
	lc.setOpaque(true);
        maker = createMakerFrame();
        lc.add(maker, JLayeredPane.PALETTE_LAYER);  
        
        add("Center", lc);
    }

    public JInternalFrame createMakerFrame() {
        JInternalFrame w;
        JBorderedPane tp;
	Container contentPane;
        
        w = new JInternalFrame("Frame Creator");
	contentPane = w.getContentPane();
        contentPane.setLayout(new GridLayout(0, 1));

        tp = new JBorderedPane();
        tp.setLayout(new GridLayout(2, 2));
        closeBox = new JCheckBox( "is Closable ");
        closeBox.setSelected(true);
        tp.add(closeBox);
        maxBox = new JCheckBox(   "is Maxable  ");
        tp.add(maxBox);
        iconBox = new JCheckBox(  "is Iconifiable ");
        tp.add(iconBox);
        resizeBox = new JCheckBox("is Resizable");
        tp.add(resizeBox);
        contentPane.add(tp);
        
        tp = new JBorderedPane();
	tp.setBorder(BorderFactory.createTitledBorder(tp, "Title"));
        tp.setLayout(new BorderLayout());
        titleField = new JTextField();
        titleField.setMinimumSize(new Dimension(50, 25));
	titleField.setEditable(true);
        titleField.setText("Frame Test 1");
        tp.add(titleField, "Center");
        contentPane.add(tp);              

        tp = new JBorderedPane();
	tp.setBorder(BorderFactory.createTitledBorder(tp, "Layer"));
        tp.setLayout(new BorderLayout());
        layerField = new JTextField();
        layerField.setMinimumSize(new Dimension(50, 25));
	layerField.setEditable(true);
        layerField.setText("5");
        tp.add(layerField, "Center");
        contentPane.add(tp);              

        tp = new JBorderedPane();
        tp.setLayout(new GridLayout(1, 2));
        closeAllButton = new JButton("Clear");
        closeAllButton.addActionListener(this);
        tp.add(closeAllButton);
        makeButton = new JButton("Make");
        makeButton.addActionListener(this);
        tp.add(makeButton);     
        contentPane.add(tp);
        
        w.setBounds(200, 10, 200, 250);
        w.setResizable(true);
        return w;
    }

    public void actionPerformed(ActionEvent e) {
        if(e.getSource() == closeAllButton) {
            lc.removeAll();
            lc.add(maker);
            lc.repaint();
            makeCount = 0;
        } else if(e.getSource() == makeButton) {
            JInternalFrame w;
	    int layer;
            w = new JInternalFrame();
            w.setClosable(closeBox.isSelected());
            w.setMaximizable(maxBox.isSelected());
            w.setIconifiable(iconBox.isSelected());
            w.setTitle(titleField.getText());
            w.setResizable(resizeBox.isSelected());
	    try { 
                layer = Integer.parseInt(layerField.getText()); 
	    } catch (NumberFormatException e2) {
	        layer = 0;
	    }
            makeCount++;
            w.setBounds(10*makeCount, 10*makeCount, 150, 100);
            if(makeCount > 10)
                makeCount = 0;
                
            w.setContentPane(new LayeredView(layer));
                
            lc.add(w, new Integer(layer));  
            try { w.setMain(true); } catch (java.beans.PropertyVetoException e2) {}
        }
    }

}

class LayeredView extends JComponent {
        Color pColor;
        int myLayer;

        public LayeredView(int layer) {
            int g = 255 - Math.abs(layer % 255);
            pColor = new Color(0,g,0);  
            myLayer = layer;
        }

        public void paint(Graphics g) {
            g.setColor(pColor);
            g.fillRect(0, 0, getWidth(), getHeight());
            if(Math.abs(myLayer % 255) < 125)
               g.setColor(Color.black);
            else
               g.setColor(Color.white);
            g.drawString("Layer "+myLayer, (getWidth() / 3), (getHeight() / 2));
        }
}

