/*
 * @(#)ProgressPanel.java	1.11 97/08/26
 * 
 * Copyright (c) 1997 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 * 
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 * 
 */
 
import com.sun.java.swing.*;
import com.sun.java.swing.text.*;

import java.awt.*;
import java.awt.event.*;
import java.util.*;


/**
 * Demo the Progress Bar
 *
 * @version 1.11 08/26/97
 * @author Jeff Dinkins
 */
public class ProgressPanel extends JBufferedPane 
{
    SwingSet swing;
    JProgressBar progressBar;
    JTextArea progressTextArea;
    JButton loadButton;
    JButton stopButton;
    LoadThread loadThread;
    boolean shouldStop;
    Object  lock = new Object();

    public ProgressPanel(SwingSet swing) {
	this.swing = swing;

	setLayout(new BoxLayout(this, BoxLayout.X_AXIS));

	JBufferedPane left = SwingSet.createVerticalPanel(true);
	JBufferedPane right = SwingSet.createHorizontalPanel(true);
        JBufferedPane layoutPanel;

	JBufferedPane textWrapper = new JBufferedPane(new BorderLayout());
	textWrapper.setBorderStyle(ETCHED);
	textWrapper.setAlignmentX(LEFT_ALIGNMENT);
	progressTextArea = new MyTextArea();
	textWrapper.add("Center", progressTextArea);

	left.add(textWrapper);
	left.add(Box.createRigidArea(swing.vpad5));
	progressBar = new JProgressBar();
	left.add(progressBar);
	left.add(Box.createRigidArea(swing.vpad10));
	// left.add(Box.createGlue());
	

	loadButton = new JButton("Start Loading Text");
	loadButton.addActionListener(new ActionListener() {
	    public void actionPerformed(ActionEvent e) {
		startLoading((JButton)e.getSource());
	    }
	});

        stopButton = new JButton("Stop Loading Text");
        stopButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                stopLoading((JButton)e.getSource());
            }
        });
        stopButton.setEnabled(false);


	right.add(Box.createGlue());
        layoutPanel = SwingSet.createVerticalPanel(false);
        layoutPanel.add(Box.createGlue());
        layoutPanel.add(loadButton);
        layoutPanel.add(Box.createRigidArea(swing.vpad20));
        layoutPanel.add(stopButton);
        layoutPanel.add(Box.createGlue());
        right.add(layoutPanel);
	right.add(Box.createGlue());

	add(left);
	add(Box.createRigidArea(swing.hpad20));
	add(right);
    }

    public void startLoading(JButton b) {
        if(loadThread == null) {
            Rectangle r;
            loadThread = new LoadThread();
            loadButton.setEnabled(false);
            stopButton.setEnabled(true);
            r = loadButton.getBounds();
            r.x = 0;
            r.y = 0;
            loadButton.paintImmediately(r);
            r = stopButton.getBounds();
            r.x = 0;
            r.y = 0;
            stopButton.paintImmediately(r);
            stopButton.requestFocus();
            shouldStop = false;
            loadThread.start();
        }
    }

    public void stopLoading(JButton b) {
        synchronized(lock) {
            shouldStop = true;
            lock.notify();
        }
    }

    class LoadThread extends Thread {
	int textLocation;
	String text =
 	 "      The saying goes: if an infinite number of monkeys\n" +
         "   typed on an infinite number of typewriters, eventually\n" +
         "   all the great works of mankind would emerge. \n\n " +
 	 "      Now, with today's high speed computers, we can\n " +
         "   finally test the theory...\n\n" +
 	 "      Lzskd jfy 92y;ho4 th;qlh sd 6yty;q2 hnlj 8sdf. Djfy\n " +
         "   92y;ho4, th;qxhz d7yty; Q0hnlj 23&^ (# ljask djf y92y;h\n " +
         "   fy92y; Sd6y ty;q2h nl jk la gfa harvin garvil lasdfsd\n " +
         "   a83sl la8z 2 be or not to be... that is the question. Hath\n" +
	 "   forth not to want a banana, or to be a banana. Banana, I \n" +
	 "   knew him banana. Banana banana banana.\n\n" +
    	 "          Well... it seemed like a good idea...\n\n\n\n\n" +
 	 "             Hi Montana!";
	LoadThread() {
	    super();
	}

	public void run () {
	    textLocation = 0;
	    progressTextArea.setText("");
	    progressBar.setValue(0);
	    progressBar.setMinimum(0);
	    progressBar.setMaximum(text.length());
	    while(progressBar.getValue() < progressBar.getMaximum() && !shouldStop) {
		progressBar.setValue(progressBar.getValue() + 1);
		progressTextArea.append(text.substring(textLocation, textLocation+1));
		textLocation++;
                synchronized(lock) {
                    if(shouldStop)
                        break;
                    try {
                        lock.wait(50);
                    } catch (java.lang.InterruptedException e) { }
                }
	    }
            loadButton.setEnabled(true);
            loadButton.repaint();
            stopButton.setEnabled(false);
            stopButton.repaint();
            loadButton.requestFocus();
            loadThread = null;
	}
    }

    class MyTextArea extends JTextArea {
        public MyTextArea() {
            // super(null, 16, 33, SCROLLBARS_NONE);
            super(null, 0, 0, SCROLLBARS_NONE);
	    setEditable(false);
        }

        public float getAlignmentX () {
            return LEFT_ALIGNMENT;
        }
 
        public float getAlignmentY () {
            return TOP_ALIGNMENT;
        }
    }
}
