/*
 * @(#)RadioButtonPanel.java	1.18 97/08/26
 * 
 * Copyright (c) 1997 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 * 
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 * 
 */

import com.sun.java.swing.*;
import com.sun.java.swing.text.*;

import java.awt.*;
import java.awt.event.*;
import java.util.*;


/**
 * RadioButtons!
 *
 * @version 1.18 08/26/97
 * @author Jeff Dinkins
 */
public class RadioButtonPanel extends JBufferedPane 
{
    // The Frame
    SwingSet swing;

    ImageIcon radio = new ImageIcon("images/WebSpice/radio.gif");
    ImageIcon radioSelected = new ImageIcon("images/WebSpice/radioSelected.gif");

    public RadioButtonPanel(SwingSet swing) {
	this.swing = swing;

	ButtonGroup group;

	setInsets(swing.insets5);
	setLayout(new BoxLayout(this, BoxLayout.X_AXIS));

	// *************** radio buttons ****************
	// text buttons
	JBufferedPane textButtons = SwingSet.createHorizontalPanel(false);
	textButtons.setAlignmentX(LEFT_ALIGNMENT);

	textButtons.setBorderStyle(ETCHED);
	textButtons.setInsets(swing.insets10);

	group = new ButtonGroup();
	JRadioButton button;
	button = new JRadioButton("One", true);
	button.setToolTipText("This is a RadioButton with Text");
	group.add(button);
        button.setKeyAccelerator('o');
	swing.radioButtons.addElement(button);
	textButtons.add(button);
	textButtons.add(Box.createRigidArea(swing.hpad10));
	
	button = new JRadioButton("Two");
	group.add(button);
        button.setKeyAccelerator('t');
	button.setToolTipText("This is a RadioButton with Text");
	swing.radioButtons.addElement(button);
	textButtons.add(button);
	textButtons.add(Box.createRigidArea(swing.hpad10));

	button = new JRadioButton("Three");
	group.add(button);
        button.setKeyAccelerator('h');
	button.setToolTipText("This is a RadioButton with Text");
	swing.radioButtons.addElement(button);
	textButtons.add(button);


	// image buttons
	group = new ButtonGroup();

	JBufferedPane imageButtons = SwingSet.createHorizontalPanel(false);
	imageButtons.setAlignmentX(LEFT_ALIGNMENT);
	imageButtons.setBorderStyle(ETCHED);
	imageButtons.setInsets(swing.insets10);

	// 1 image
	button = new JRadioButton(swing.duke2);
	group.add(button);
	button.setSelectedIcon(swing.dukeWave);
	button.setSelected(true);
	button.setToolTipText("This is a RadioButton with a Icon");
	swing.radioButtons.addElement(button);
	imageButtons.add(button);
	imageButtons.add(Box.createRigidArea(swing.hpad10));
	
	// 2 images
	button = new JRadioButton(swing.duke2);
	group.add(button);
	swing.radioButtons.addElement(button);
	button.setSelectedIcon(swing.dukeWave);
	button.setToolTipText("This is a RadioButton with a Icon");
	imageButtons.add(button);
	imageButtons.add(Box.createRigidArea(swing.hpad10));

	// 3 images
	button = new JRadioButton(swing.duke2);
	group.add(button);
	button.setSelectedIcon(swing.dukeWave);
	button.setToolTipText("This is a RadioButton with a Icon");
	swing.radioButtons.addElement(button);
	imageButtons.add(button);

	// text&image buttons
	group = new ButtonGroup();

	JBufferedPane tiButtons = SwingSet.createHorizontalPanel(false);
	tiButtons.setAlignmentX(LEFT_ALIGNMENT);
	tiButtons.setBorderStyle(ETCHED);
	tiButtons.setInsets(swing.insets10);

	button = new JRadioButton("Left", radio);
	group.add(button);
	button.setToolTipText("This is a RadioButton with a Icon and Text");
	button.setSelected(true);
	button.setSelectedIcon(radioSelected);
	swing.radioButtons.addElement(button);
	tiButtons.add(button);
	tiButtons.add(Box.createRigidArea(swing.hpad10));

	button = new JRadioButton("Center", radio);
	group.add(button);
	swing.radioButtons.addElement(button);
	button.setToolTipText("This is a RadioButton with a Icon and Text");
	button.setSelectedIcon(radioSelected);
	tiButtons.add(button);
	tiButtons.add(Box.createRigidArea(swing.hpad10));

	button = new JRadioButton("Right", radio);
	group.add(button);
	swing.radioButtons.addElement(button);
	button.setToolTipText("This is a RadioButton with a Icon and Text");
	button.setSelectedIcon(radioSelected);
	tiButtons.add(button);
	tiButtons.add(Box.createHorizontalBox());

	// Add button panels to buttonPanel
	JBufferedPane buttonPanel = SwingSet.createVerticalPanel(true);
	buttonPanel.setAlignmentX(LEFT_ALIGNMENT);
	buttonPanel.setAlignmentY(TOP_ALIGNMENT);

	JLabel l = (JLabel) buttonPanel.add(new JLabel("Text RadioButtons"));
	l.setFont(swing.boldFont);
	buttonPanel.add(textButtons);

	buttonPanel.add(Box.createVerticalStrut(10));

	l = (JLabel) buttonPanel.add(new JLabel("Image RadioButtons"));
	l.setFont(swing.boldFont);
	buttonPanel.add(imageButtons);

	buttonPanel.add(Box.createVerticalStrut(10));

	l = (JLabel) buttonPanel.add(new JLabel("Image & Text RadioButtons"));
	l.setFont(swing.boldFont);
	buttonPanel.add(tiButtons);
	buttonPanel.add(tiButtons);
	buttonPanel.add(Box.createGlue());


	// *************** Create the button controls ****************
	JBufferedPane controls = new JBufferedPane() {
	    public Dimension getMaximumSize() {
		return new Dimension(300, super.getMaximumSize().height);
	    }
	};
	controls.setLayout(new BoxLayout(controls, BoxLayout.Y_AXIS));
	controls.setAlignmentY(TOP_ALIGNMENT);
	controls.setAlignmentX(LEFT_ALIGNMENT);

	JBufferedPane buttonControls = SwingSet.createHorizontalPanel(true);
	buttonControls.setAlignmentY(TOP_ALIGNMENT);
	buttonControls.setAlignmentX(LEFT_ALIGNMENT);

	JBufferedPane leftColumn = SwingSet.createVerticalPanel(false);
	leftColumn.setAlignmentX(LEFT_ALIGNMENT);
	leftColumn.setAlignmentY(TOP_ALIGNMENT);

	JBufferedPane rightColumn = SwingSet.createVerticalPanel(false);
	rightColumn.setAlignmentX(LEFT_ALIGNMENT);
	rightColumn.setAlignmentY(TOP_ALIGNMENT);

	buttonControls.add(leftColumn);
	buttonControls.add(Box.createRigidArea(swing.hpad20));
	buttonControls.add(rightColumn);
	buttonControls.add(Box.createRigidArea(swing.hpad20));

	controls.add(buttonControls);

	// Display Options
	l = new JLabel("Display Options:");
	leftColumn.add(l);
	l.setFont(swing.boldFont);

 	JCheckBox bordered = new JCheckBox("Paint Border");
	bordered.setToolTipText("Click here to turn border painting on or off.");
        bordered.setKeyAccelerator('b');
 	bordered.addItemListener(swing.buttonDisplayListener);
 	leftColumn.add(bordered);
 
 	JCheckBox focused = new JCheckBox("Paint Focus");
	focused.setToolTipText("Click here to turn focus painting on or off.");
        focused.setKeyAccelerator('f');
 	focused.setSelected(true);
 	focused.addItemListener(swing.buttonDisplayListener);
 	leftColumn.add(focused);

	JCheckBox enabled = new JCheckBox("Enabled");
	enabled.setSelected(true);
	enabled.setToolTipText("Click here to enable or disable the radio buttons.");
        enabled.setKeyAccelerator('e');
	enabled.addItemListener(swing.buttonDisplayListener);
	leftColumn.add(enabled);
 

	leftColumn.add(Box.createRigidArea(swing.vpad20));

	
	l = new JLabel("Pad Amount:");
	leftColumn.add(l);
	l.setFont(swing.boldFont);
	
	group = new ButtonGroup();
	JRadioButton defaultPad = new JRadioButton("Default");
        defaultPad.setKeyAccelerator('d');
	defaultPad.setToolTipText("Uses the default padding between the border and label.");
	group.add(defaultPad);
	defaultPad.setSelected(true);
 	defaultPad.addItemListener(swing.buttonPadListener);
	leftColumn.add(defaultPad);

	JRadioButton zeroPad = new JRadioButton("0");
        zeroPad.setKeyAccelerator('0');
	group.add(zeroPad);
	zeroPad.setToolTipText("Uses no padding between the border and label.");
 	zeroPad.addItemListener(swing.buttonPadListener);
	leftColumn.add(zeroPad);

	JRadioButton tenPad = new JRadioButton("10");
        tenPad.setKeyAccelerator('1');
	tenPad.setToolTipText("Uses a 10 pixel pad between the border and label.");
	group.add(tenPad);
 	tenPad.addItemListener(swing.buttonPadListener);
	leftColumn.add(tenPad);
	
	leftColumn.add(Box.createRigidArea(swing.vpad20));

	l = new JLabel("Size:");
	leftColumn.add(l);
	l.setFont(swing.boldFont);

	group = new ButtonGroup();
	JRadioButton prefSize = new JRadioButton("PreferredSize");
	prefSize.addActionListener(swing.sizeListener);
	prefSize.setToolTipText("Set the radio button's size to its PreferredSize.");
	prefSize.setSelected(true);
	group.add(prefSize);
	leftColumn.add(prefSize);

	JRadioButton maxSize = new JRadioButton("MaximumSize");
	maxSize.addActionListener(swing.sizeListener);
	maxSize.setToolTipText("Set the radio button's size to use as much room as is available.");
	group.add(maxSize);
	leftColumn.add(maxSize);

	// *************** Create the layout controls ****************
	// Create Text Position Layout control
	JBufferedPane textPosition = DirectionButton.createDirectionPanel(true, "E", swing.textPositionListener);
	JBufferedPane labelAlignment = DirectionButton.createDirectionPanel(true, "C", swing.labelAlignmentListener);

	l = new JLabel("Text Position:");
	rightColumn.add(l);
	l.setFont(swing.boldFont);
 	rightColumn.add(textPosition);

 	rightColumn.add(Box.createRigidArea(swing.vpad20));

	l = new JLabel("Content Alignment:");
	rightColumn.add(l);
	l.setFont(swing.boldFont);
 	rightColumn.add(labelAlignment);

 	rightColumn.add(Box.createGlue());

	add(buttonPanel);
	add(Box.createRigidArea(swing.hpad10));
 	add(controls);
    }

    
}
