/*
 * @(#)SpringsPane.java	1.1 97/08/27
 * Copyright (c) 1997 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 */

import com.sun.java.swing.*;
import com.sun.java.swing.border.*;

import java.awt.Panel;
import java.awt.Color;
import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.awt.Font;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Color;
import java.awt.Rectangle;
import java.awt.Insets;

/*
 * @version 1.1 08/27/97
 * @author Dave Kloba
 */
public class SpringsPane extends JBufferedPane implements ActionListener {
    JBorderedPane horizPane, vertPane, configPane;
    SpringLayout hLayout, vLayout, cLayout;
    JButton widget;
    
    ImageIcon vSpring = new ImageIcon("images/spring_v.gif");
    ImageIcon hSpring = new ImageIcon("images/spring_h.gif");
    ImageIcon vStrut = new ImageIcon("images/strut_v.gif");
    ImageIcon hStrut = new ImageIcon("images/strut_h.gif");
    
    ImageIcon allSprings = new ImageIcon("images/allSprings.gif");
    ImageIcon allStruts = new ImageIcon("images/allStruts.gif");
    ImageIcon widthSpring = new ImageIcon("images/widthSpring.gif");
    ImageIcon heightSpring = new ImageIcon("images/heightSpring.gif");
    
    Insets insets0 = new Insets(0,0,0,0);
    
    int DELTA_CHANGE = 30;
    int PANEL_WIDTH = 620 - DELTA_CHANGE;
    int PANEL_HEIGHT = 300 - DELTA_CHANGE;
    
    public SpringsPane()       {
        setLayout(new SpringLayout());
        setSize(PANEL_WIDTH, PANEL_HEIGHT);
    
        createHorizPane();
        createVertPane();
        createConfigurator();
        createDescription();
    
        // This is a hack to resize the components, so the user can see
        // the effects of the springs. Normally you don't need to call this.
	doLayout();
        setSize(PANEL_WIDTH + DELTA_CHANGE, PANEL_HEIGHT + DELTA_CHANGE);
    }
    
    public void actionPerformed(ActionEvent e) {
        SpringLayout layout = ((SpringLayout)widget.getParent().getLayout());
        JButton button = (JButton)e.getSource();
        int     currentMask;
        boolean isStrut = true;
    
        currentMask = layout.getSprings(widget);
        if(e.getActionCommand().equals("Top"))      {
            layout.setSprings(widget, currentMask ^ SpringLayout.TOP_MARGIN_CAN_CHANGE);
            if((currentMask & SpringLayout.TOP_MARGIN_CAN_CHANGE) != 0)
		button.setIcon(vStrut);
            else
		button.setIcon(vSpring);
        } else if(e.getActionCommand().equals("Left"))      {
            layout.setSprings(widget, currentMask ^ SpringLayout.LEFT_MARGIN_CAN_CHANGE);
            if((currentMask & SpringLayout.LEFT_MARGIN_CAN_CHANGE) != 0)
		button.setIcon(hStrut);
            else
		button.setIcon(hSpring);
        } else if(e.getActionCommand().equals("Right"))     {
            layout.setSprings(widget, currentMask ^ SpringLayout.RIGHT_MARGIN_CAN_CHANGE);
            if((currentMask & SpringLayout.RIGHT_MARGIN_CAN_CHANGE) != 0)
		button.setIcon(hStrut);
            else
		button.setIcon(hSpring);
        } else if(e.getActionCommand().equals("Bottom"))    {
            layout.setSprings(widget, currentMask ^ SpringLayout.BOTTOM_MARGIN_CAN_CHANGE);
            if((currentMask & SpringLayout.BOTTOM_MARGIN_CAN_CHANGE)  != 0)
		button.setIcon(vStrut);
            else
		button.setIcon(vSpring);
        } else if(e.getActionCommand().equals("Widget"))    {
            String text = e.getActionCommand();
            if((currentMask & SpringLayout.HEIGHT_CAN_CHANGE) != 0
                && (currentMask & SpringLayout.WIDTH_CAN_CHANGE) !=0 )	{
	            button.setIcon(heightSpring);
	            layout.setSprings(widget, currentMask ^ SpringLayout.WIDTH_CAN_CHANGE);
            } else if((currentMask & SpringLayout.HEIGHT_CAN_CHANGE) != 0)	{
                button.setIcon(widthSpring);
                layout.setSprings(widget, currentMask ^
                				(SpringLayout.HEIGHT_CAN_CHANGE
                					| SpringLayout.WIDTH_CAN_CHANGE));
            } else if((currentMask & SpringLayout.WIDTH_CAN_CHANGE) != 0)	{
                button.setIcon(allStruts);
                layout.setSprings(widget, currentMask ^ SpringLayout.WIDTH_CAN_CHANGE);
            } else {
                button.setIcon(allSprings);
                layout.setSprings(widget,
                currentMask | SpringLayout.WIDTH_CAN_CHANGE | SpringLayout.HEIGHT_CAN_CHANGE);
            }
        }
        layout.layoutContainer(widget.getParent());
        widget.getParent().repaint();
    }
    
    // SET UP THE HORIZONTAL TESTS
    public void createHorizPane() {
        int _x, _y;
        int DEFAULT_HEIGHT = 16;
        int DEFAULT_WIDTH = 130;
        int NUM_BUTTONS = 7;
        Insets i;
	JButton button;    

        horizPane = new JBorderedPane();
        horizPane.setBorder(BorderFactory.createTitledBorder(horizPane, "Horizontal Settings"));
        horizPane.setLocation(0, 0);
        add(horizPane, SpringLayout.WIDTH_SPRING);
    
        hLayout = (SpringLayout)horizPane.getLayout();
        i = horizPane.getInsets();
        _x = i.left;
        _y = i.top;
    
        horizPane.setSize(PANEL_WIDTH / 2, PANEL_HEIGHT / 2);
    
        DEFAULT_HEIGHT = ((PANEL_HEIGHT / 2) - i.top - i.bottom) / NUM_BUTTONS;
        DEFAULT_WIDTH = ((PANEL_WIDTH / 2) - i.left - i.right);
    
        button = new JButton("Left");
        button.setPad(insets0);
        hLayout.setSprings(button, SpringLayout.LEFT_MARGIN_CAN_CHANGE);
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _y += DEFAULT_HEIGHT;
        horizPane.add(button);
    
        button = new JButton("Left + Width");
        button.setPad(insets0);
        hLayout.setSprings(button, SpringLayout.WIDTH_CAN_CHANGE
    		       | SpringLayout.LEFT_MARGIN_CAN_CHANGE);
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _y += DEFAULT_HEIGHT;
        horizPane.add(button);
    
        button = new JButton("Right");
        button.setPad(insets0);
        hLayout.setSprings(button, SpringLayout.RIGHT_MARGIN_CAN_CHANGE);
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _y += DEFAULT_HEIGHT;
        horizPane.add(button);
    
        button = new JButton("Right + Width");
        button.setPad(insets0);
        hLayout.setSprings(button, SpringLayout.WIDTH_CAN_CHANGE
    		       | SpringLayout.RIGHT_MARGIN_CAN_CHANGE);
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _y += DEFAULT_HEIGHT;
        horizPane.add(button);
    
        button = new JButton("Left + Right");
        button.setPad(insets0);
        hLayout.setSprings(button, SpringLayout.RIGHT_MARGIN_CAN_CHANGE
    		       | SpringLayout.LEFT_MARGIN_CAN_CHANGE);
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _y += DEFAULT_HEIGHT;
        horizPane.add(button);
    
        button = new JButton("Left + Width + Right");
        button.setPad(insets0);
        hLayout.setSprings(button, SpringLayout.RIGHT_MARGIN_CAN_CHANGE
    		       | SpringLayout.LEFT_MARGIN_CAN_CHANGE
    		       | SpringLayout.WIDTH_CAN_CHANGE);
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _y += DEFAULT_HEIGHT;
        horizPane.add(button);
    
        button = new JButton("Width");
        button.setPad(insets0);
        hLayout.setSprings(button, SpringLayout.WIDTH_CAN_CHANGE);
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _y += DEFAULT_HEIGHT;
        horizPane.add(button);
    }    
    
    // SET UP THE VERTICAL TESTS
    public void createVertPane() {
        int _x, _y;
        int DEFAULT_HEIGHT = 120;
        int DEFAULT_WIDTH = 42;
        int NUM_BUTTONS = 7;
        Insets i;
	JButton button;    

        vertPane = new JBorderedPane();
        vertPane.setBorder(BorderFactory.createTitledBorder(vertPane, "Vertical Settings"));
        vertPane.setLocation(horizPane.getBounds().x + horizPane.getBounds().width, 0);
        ((SpringLayout)getLayout()).setSprings(vertPane, SpringLayout.HEIGHT_CAN_CHANGE 
    							| SpringLayout.LEFT_MARGIN_CAN_CHANGE);
        add(vertPane);
    
        vLayout = (SpringLayout)vertPane.getLayout();
        i = vertPane.getInsets();
        _x = i.left;
        _y = i.top;
    
        vertPane.setSize(PANEL_WIDTH / 2, PANEL_HEIGHT / 2);
    
        DEFAULT_HEIGHT = ((PANEL_HEIGHT / 2) - i.top - i.bottom);
        DEFAULT_WIDTH = ((PANEL_WIDTH / 2) - i.left - i.right) / NUM_BUTTONS;
    
        button = new JButton("T");
        button.setPad(insets0);
        vLayout.setSprings(button, SpringLayout.TOP_MARGIN_CAN_CHANGE);
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _x += DEFAULT_WIDTH;
        vertPane.add(button);
    
        button = new JButton("T/H");
        button.setPad(insets0);
        vLayout.setSprings(button, SpringLayout.TOP_MARGIN_CAN_CHANGE
    		       | SpringLayout.HEIGHT_CAN_CHANGE);
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _x += DEFAULT_WIDTH;
        vertPane.add(button);
    
        button = new JButton("B");
        button.setPad(insets0);
        vLayout.setSprings(button, SpringLayout.BOTTOM_MARGIN_CAN_CHANGE );
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _x += DEFAULT_WIDTH;
        vertPane.add(button);
    
        button = new JButton("B/H");
        button.setPad(insets0);
        vLayout.setSprings(button, SpringLayout.BOTTOM_MARGIN_CAN_CHANGE
    		       | SpringLayout.HEIGHT_CAN_CHANGE);
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _x += DEFAULT_WIDTH;
        vertPane.add(button);
    
        button = new JButton("T/B");
        button.setPad(insets0);
        vLayout.setSprings(button, SpringLayout.BOTTOM_MARGIN_CAN_CHANGE
    		       | SpringLayout.TOP_MARGIN_CAN_CHANGE);
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _x += DEFAULT_WIDTH;
        vertPane.add(button);
    
        button = new JButton("T/H/B");
        button.setPad(insets0);
        vLayout.setSprings(button, SpringLayout.BOTTOM_MARGIN_CAN_CHANGE
    		       | SpringLayout.TOP_MARGIN_CAN_CHANGE
    		       | SpringLayout.HEIGHT_CAN_CHANGE);
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _x += DEFAULT_WIDTH;
        vertPane.add(button);
    
        button = new JButton("H");
        button.setPad(insets0);
        vLayout.setSprings(button, SpringLayout.HEIGHT_CAN_CHANGE);
        button.setFocusPainted(false);
        button.setBounds(_x, _y, DEFAULT_WIDTH, DEFAULT_HEIGHT);
        _x += DEFAULT_WIDTH;
        vertPane.add(button);
    
    }
    
    // SET UP THE INTERACTIVE VERSION
    public void createConfigurator() {
        int _x, _y;
        Insets i;
        int cWidth, cHeight;
        int depth;
        JButton t, b, l, r;
    
        configPane = new JBorderedPane();
        configPane.setLocation(0, horizPane.getBounds().y + horizPane.getBounds().height);
        configPane.setBorder(BorderFactory.createTitledBorder(configPane, "Configurator"));
        cLayout = (SpringLayout)configPane.getLayout();
        add(configPane);
    
        ((SpringLayout)getLayout()).setSprings(configPane, SpringLayout.HEIGHT_CAN_CHANGE 
    							| SpringLayout.WIDTH_CAN_CHANGE);
        
        cLayout = (SpringLayout)vertPane.getLayout();
        i = configPane.getInsets();
        _x = i.left;
        _y = i.top;
    
        cWidth = PANEL_WIDTH / 2;
        cHeight = PANEL_HEIGHT  / 2;
        configPane.setSize(cWidth, cHeight);
    
        cWidth = cWidth - i.left - i.right;
        cHeight = cHeight - i.top - i.bottom;
    
        depth = vSpring.getHeight() + 4;
    
        t = new JButton();
        t.setPad(insets0);
        t.setActionCommand("Top");
        t.setIcon(vSpring);
        t.setPressedIcon(vSpring);
        t.addActionListener(this);
        t.setFocusPainted(false);
        t.setBounds(i.left, i.top, cWidth, depth);
        cLayout.setSprings(t, SpringLayout.BOTTOM_MARGIN_CAN_CHANGE
    		       | SpringLayout.WIDTH_CAN_CHANGE);
        configPane.add(t);
    
        r = new JButton();
        r.setPad(insets0);
        r.setActionCommand("Right");
        r.setIcon(hSpring);
        r.setPressedIcon(hSpring);
        r.addActionListener(this);
        r.setFocusPainted(false);
        r.setBounds(cWidth - depth + i.right, t.getBounds().y+ t.getBounds().height, 
					depth, cHeight - depth - depth);
        cLayout.setSprings(r, SpringLayout.LEFT_MARGIN_CAN_CHANGE
    		       			| SpringLayout.HEIGHT_CAN_CHANGE);
        configPane.add(r);
    
        l = new JButton();
        l.setPad(insets0);
        l.setActionCommand("Left");
        l.setIcon(hSpring);
        l.setPressedIcon(hSpring);
        l.addActionListener(this);
        l.setFocusPainted(false);
        l.setBounds(i.left, r.getBounds().y, r.getBounds().width, r.getBounds().height);
        cLayout.setSprings(l, SpringLayout.RIGHT_MARGIN_CAN_CHANGE
    		       | SpringLayout.HEIGHT_CAN_CHANGE);
        configPane.add(l);
    
        b = new JButton();
        b.setPad(insets0);
        b.setIcon(vSpring);
        b.setPressedIcon(vSpring);
        b.setActionCommand("Bottom");
        b.addActionListener(this);
        b.setFocusPainted(false);
        b.setBounds(t.getBounds().x, l.getBounds().y + l.getBounds().height, 
    		    t.getBounds().width, t.getBounds().height);
        cLayout.setSprings(b, SpringLayout.TOP_MARGIN_CAN_CHANGE
    		       | SpringLayout.WIDTH_CAN_CHANGE);
        configPane.add(b);
    
        widget = new JButton();
        widget.setPad(insets0);
        widget.setActionCommand("Widget");
        widget.addActionListener(this);
        widget.setIcon(allStruts);
        widget.setFocusPainted(false);
        cLayout.setSprings(widget, SpringLayout.TOP_MARGIN_CAN_CHANGE
    			| SpringLayout.BOTTOM_MARGIN_CAN_CHANGE
    			| SpringLayout.RIGHT_MARGIN_CAN_CHANGE
    			| SpringLayout.LEFT_MARGIN_CAN_CHANGE);
        widget.setBounds(l.getBounds().x + l.getBounds().width,
    			t.getBounds().y + t.getBounds().height,
    			cWidth - (depth *2), cHeight - (depth*2));
        configPane.add(widget);
    }
    
    // Load the description
    public void createDescription() {
        JBorderedPane descrPane = new JBorderedPane();
        descrPane.setLocation(configPane.getBounds().x + configPane.getBounds().width, 
    				vertPane.getBounds().y + vertPane.getBounds().height);
        descrPane.setBorder(BorderFactory.createTitledBorder(descrPane, "Instructions"));
        descrPane.setLayout(new BorderLayout());
        descrPane.setSize(PANEL_WIDTH / 2, PANEL_HEIGHT  / 2);
    
        add(descrPane);
    
        ((SpringLayout)getLayout()).setSprings(descrPane, SpringLayout.TOP_MARGIN_CAN_CHANGE 
    							| SpringLayout.LEFT_MARGIN_CAN_CHANGE);
    
        String text = SwingSet.contentsOfFile("springStrutHelp.txt");
        JTextArea ta = new JTextArea(text);
        ta.setEditable(false);
        ta.setForeground(Color.black);
        ta.setBackground(Color.white);
    
        descrPane.add(ta, "Center");	
    }
}

