/*
 * @(#)SwingSet.java	1.131 97/09/04
 *
 * Copyright (c) 1997 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 */

import com.sun.java.swing.*;
import com.sun.java.swing.event.*;
import com.sun.java.swing.text.*;
import com.sun.java.swing.border.*;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.io.*;

/**
 * A demo that shows all of the Swing components.
 *
 * @version 1.131 09/04/97
 * @author Jeff Dinkins
 * @author Chester Rose
 * @author ...and the rest of the JFC Swing Team
 */
public class SwingSet extends JBufferedPane
{
    // This
    SwingSet swing;

    // The Frame
    public static JFrame frame;

    // Current ui
    public String currentUI = "Basic";

    // The width and height of the frame
    public static int WIDTH = 645;
    public static int HEIGHT = 525;
    public static int INITIAL_WIDTH = 400;
    public static int INITIAL_HEIGHT = 200;

    public final static Dimension hpad5 = new Dimension(5,1);
    public final static Dimension hpad10 = new Dimension(10,1);
    public final static Dimension hpad20 = new Dimension(20,1);
    public final static Dimension hpad40 = new Dimension(40,1);
    public final static Dimension hpad80 = new Dimension(80,1);

    public final static Dimension vpad5 = new Dimension(1,5);
    public final static Dimension vpad10 = new Dimension(1,10);
    public final static Dimension vpad20 = new Dimension(1,20);
    public final static Dimension vpad40 = new Dimension(1,40);
    public final static Dimension vpad80 = new Dimension(1,80);

    public final static Insets insets0 = new Insets(0,0,0,0);
    public final static Insets insets5 = new Insets(5,5,5,5);
    public final static Insets insets10 = new Insets(10,10,10,10);
    public final static Insets insets15 = new Insets(15,15,15,15);
    public final static Insets insets20 = new Insets(20,20,20,20);

    public Font defaultFont = new Font("Dialog", Font.PLAIN, 12);
    public Font boldFont = new Font("Dialog", Font.BOLD, 12);
    public Font bigFont = new Font("Dialog", Font.PLAIN, 18);
    public Font bigBoldFont = new Font("Dialog", Font.BOLD, 18);
    public Font reallyBigFont = new Font("Dialog", Font.PLAIN, 18);
    public Font reallyBigBoldFont = new Font("Dialog", Font.BOLD, 24);

    // Some images used in the demo
    public ImageIcon duke           = new ImageIcon("images/duke.gif");
    public ImageIcon duke2          = new ImageIcon("images/duke2.gif");
    public ImageIcon dukeSnooze     = new ImageIcon("images/dukeSnooze.gif");
    public ImageIcon dukeWave       = new ImageIcon("images/dukeWave.gif");
    public ImageIcon dukeMagnify    = new ImageIcon("images/dukeMagnify.gif");

    public ImageIcon cow            = new ImageIcon("images/cowSmall.gif");

    public ImageIcon tiger          = new ImageIcon("images/BigTiger.gif");
    public ImageIcon littleTiger    = new ImageIcon("images/SmallTiger.gif");

    public ImageIcon upButton       = new ImageIcon("images/buttonImage2.gif");
    public ImageIcon downButton     = new ImageIcon("images/buttonImage3.gif");
    public ImageIcon disabledButton = new ImageIcon("images/buttonImage4.gif");


    // The panels used in the demo
    public JBufferedPane borderPanel;
    public JBufferedPane buttonPanel;
    public JBufferedPane checkboxPanel;
    public JBufferedPane dateChooserPanel;
    public JBufferedPane debugGraphicsPanel;
    public JBufferedPane labelPanel;
    public JBufferedPane comboBoxPanel;
    public JBufferedPane listBoxPanel;
    public JBufferedPane logoPanel;
    public JBufferedPane menuPanel;
    public JBufferedPane progressBarPanel;
    public JBufferedPane radioButtonPanel;
    // public JPanel scrollBarPanel;
    public JBufferedPane scrollPanePanel;
    public JBufferedPane sliderPanel;
    public JBufferedPane springsAndStrutsPanel;
    public JBufferedPane tablePanel;
    public JBufferedPane textPanel;
    public JBufferedPane borderedPanePanel;
    public JBufferedPane toolTipPanel;
    public JBufferedPane treePanel;
    public JBufferedPane windowPanel;

    // Progress
    public static int totalPanels = 21;
    public static int currentProgressValue = 0;
    public static JLabel progressLabel = null;
    public static JProgressBar progressBar = null;

    public Component previousPage;

    public Vector currentControls;
    public Vector labels = new Vector();
    public Vector buttons = new Vector();
    public Vector checkboxes = new Vector();
    public Vector radioButtons = new Vector();

    // Some components used in the demo
    public JTabbedPane tabbedPane;
    public JBorderedPane borderedPane;
    public JListBox listBox;
    public BigScrollPane bigScrollPane;

    // Progress
    int total = 21;

    /*******************************************/
    /****** Construct the SwingSet demo ********/
    /*******************************************/
    public SwingSet() {
	super(true); // double buffer
	swing = this;
	setName("Main SwingSet Panel");
	DebugGraphics.setFlashTime(30);
	setFont(defaultFont);
	setLayout(new BorderLayout());

	// Add a MenuBar
	add("North", createMenuBar());

	// Add interior panel
	GridBagLayout gridbag = new GridBagLayout();
	JBufferedPane interior = new JBufferedPane(gridbag);
	interior.setBuffered(false);
	interior.setName("Interior Swing Panel");
 	interior.setInsets(new Insets(10,5,10,5));
	interior.setLayout(gridbag);
	GridBagConstraints constraints = new GridBagConstraints();
        constraints.gridx = 1;
        constraints.gridy = 1;
        constraints.anchor = GridBagConstraints.WEST;
	add("Center", interior);

	// Create a tab pane
	tabbedPane = new JTabbedPane();
        // Add magic key to enable timer logging
        tabbedPane.registerKeyboardAction(new ToggleLogging(), KeyStroke.getKeyStroke('l', InputEvent.ALT_MASK), WHEN_IN_FOCUSED_WINDOW);

	tabbedPane.setFont(defaultFont);
        constraints.weightx = 1;
        constraints.weighty = 1;
        constraints.fill = GridBagConstraints.BOTH;
	gridbag.setConstraints(tabbedPane, constraints);
	interior.add(tabbedPane);

	constraints.gridx++;
        constraints.insets = new Insets(0,10,0,0);

	// Add the Button panel
	progressLabel.setText("Loading Title Page");
	ImageIcon swingLogo = new ImageIcon("images/swingLabelSmall.gif");
	JBufferedPane logoPanel = createLogo();
	tabbedPane.addTab("", swingLogo, logoPanel);
	tabbedPane.setSelectedIndex(0);
	progressBar.setValue(++currentProgressValue);

	// Buttons
	progressLabel.setText("Loading Button Example");
	buttonPanel = new ButtonPanel(this);
	tabbedPane.addTab("Buttons", null, buttonPanel);
	progressBar.setValue(++currentProgressValue);

	// RadioButtons
	progressLabel.setText("Loading RadioButton Example");
	radioButtonPanel = new RadioButtonPanel(this);
	tabbedPane.addTab("RadioButtons", null, radioButtonPanel);
	progressBar.setValue(++currentProgressValue);

	// Checkboxs
	progressLabel.setText("Loading Checkbox Example");
	checkboxPanel = new CheckboxPanel(this);
	tabbedPane.addTab("Checkboxes", null, checkboxPanel);
	progressBar.setValue(++currentProgressValue);

	// Labels
	progressLabel.setText("Loading Label Example");
	labelPanel = new LabelPanel(this);
	tabbedPane.addTab("Labels", null, labelPanel);
	progressBar.setValue(++currentProgressValue);

	// Borders
	progressLabel.setText("Loading Border Example");
	borderPanel = new BorderPanel();
	tabbedPane.addTab("Borders", null, borderPanel);
	progressBar.setValue(++currentProgressValue);

	// ComboBox
	progressLabel.setText("Loading ComboBox Example");
	comboBoxPanel = new ComboBoxPanel(this);
	tabbedPane.addTab("ComboBox",null,comboBoxPanel);
	progressBar.setValue(++currentProgressValue);
	// This is unfortunately needed right now, since JComboBox
	// has no way to know when an ancestor is removed from
	// the hierarchy so that it can hide its JPopupMenu.  We
	// do this explicitly here so that menus aren't left
	// hanging when you switch tabs -- better underlying 
	// support will exist in future versions.
	tabbedPane.addContainerListener(new ContainerAdapter() {
	    public void componentRemoved(ContainerEvent e) {
		Component c = e.getChild();
		if ((c == comboBoxPanel) && (c instanceof ComboBoxPanel)) 
		    ((ComboBoxPanel)c).hideAllPopups();
	    }

	});

	// DebugGraphics
	progressLabel.setText("Loading DebugGraphics Example");
	debugGraphicsPanel = new DebugGraphicsPanel(this);
	tabbedPane.addTab("DebugGraphics", null, debugGraphicsPanel);
	progressBar.setValue(++currentProgressValue);

	// Internal Frame
	progressLabel.setText("Loading Internal Frame Example");
	windowPanel = new InternalWindowPanel();
	tabbedPane.addTab("Internal Frame", null, windowPanel);
	progressBar.setValue(++currentProgressValue);

	// ListBox
	progressLabel.setText("Loading ListBox Example");
	listBoxPanel = new ListPanel(this);
	tabbedPane.addTab("ListBox", null, listBoxPanel);
	progressBar.setValue(++currentProgressValue);

	// Menus
	progressLabel.setText("Loading Menu Example");
	menuPanel = createMenus();
	tabbedPane.addTab("Menus & ToolBars", null, menuPanel);
	progressBar.setValue(++currentProgressValue);
	// This is unfortunately needed right now, since JMenu
	// has no way to know when an ancestor is removed from
	// the hierarchy so that it can deselect itself.  We
	// do this explicitly here so that menus aren't left
	// hanging when you switch tabs -- better underlying 
	// support will exist in future versions.
	tabbedPane.addContainerListener(new ContainerAdapter() {
	    public void componentRemoved(ContainerEvent e) {
		Component c = e.getChild();
		if (c == menuPanel) 
		    menuBar.setSelected(null);
	    }

	});

	// ProgressBar
	progressLabel.setText("Loading ProgressBar Example");
	progressBarPanel = new ProgressPanel(this);
	tabbedPane.addTab("ProgressBar", null, progressBarPanel);
	progressBar.setValue(++currentProgressValue);


	// ScrollBar
	/*
	progressLabel.setText("Loading ScrollBar Example");
	scrollBarPanel = createScrollBar();
	tabbedPane.addTab("ScrollBars", littleTiger, scrollBarPanel);
	progressBar.setValue(++currentProgressValue);
	*/

	// ScrollPane
	progressLabel.setText("Loading ScrollPane Example");
	scrollPanePanel = new ScrollPanePanel();
	tabbedPane.addTab("ScrollPane", littleTiger, scrollPanePanel);
	progressBar.setValue(++currentProgressValue);


	// Sliders
	progressLabel.setText("Loading Slider Example");
	sliderPanel = new SliderPanel();
	tabbedPane.addTab("Slider", null, sliderPanel);
	progressBar.setValue(++currentProgressValue);

	// Springs & Struts
	progressLabel.setText("Loading Springs and Struts Example");
	springsAndStrutsPanel = createSpringsAndStruts();
	tabbedPane.addTab("Springs & Struts", null, springsAndStrutsPanel);
	progressBar.setValue(++currentProgressValue);

	// Table
	progressLabel.setText("Loading Table Example");
	tablePanel = new TablePanel(swing);
	tabbedPane.addTab("TableView", null, tablePanel);
	progressBar.setValue(++currentProgressValue);

	// Text
	progressLabel.setText("Loading Text Example");
	textPanel = new TextPanel(swing);
	tabbedPane.addTab("TextFields & TextArea", null, textPanel);
	progressBar.setValue(++currentProgressValue);

	// borderedPane
	progressLabel.setText("Loading BorderedPane Example");
	borderedPanePanel = new BorderedPanePanel(this);
	tabbedPane.addTab("BorderedPane", null, borderedPanePanel);
	progressBar.setValue(++currentProgressValue);

	// ToolTips
	progressLabel.setText("Loading ToolTip Example");
	toolTipPanel = new ToolTipPanel();
	tabbedPane.addTab("ToolTips", cow, toolTipPanel);
	progressBar.setValue(++currentProgressValue);

	// TreeView
	progressLabel.setText("Loading TreeView Example");
	treePanel = new TreePanel(this);
	tabbedPane.addTab("TreeView", null, treePanel);
	progressBar.setValue(++currentProgressValue);

	// Add the L&F toggle button
	JBufferedPane toggleUIPanel = createToggleUIButtons();
	add("South", toggleUIPanel);

	// Add Tab change listener
	createTabListener();

    }

    class ToggleLogging extends DefaultAction {
        public void actionPerformed(ActionEvent e) {
            System.out.println("In here");
           Timer.setLogTimers(!Timer.getLogTimers());
        }

        public boolean isEnabled() {
            return true;
        }
    }

    /*******************************************/
    /************ create components ************/
    /*******************************************/

    /**
     * MenuBar
     */
    Dialog aboutBox;
    JCheckBoxMenuItem cb;
    JMenuBar createMenuBar() {
	// MenuBar
	JMenuBar menuBar = new JMenuBar();

	JMenuItem mi;

	// File Menu
	JMenu file = (JMenu) menuBar.add(new JMenu("File"));
        mi = (JMenuItem) file.add(new JMenuItem("About"));
	mi.addActionListener(new ActionListener() {
	    public void actionPerformed(ActionEvent e) {
		// tabbedPane.setSelectedIndex(0);
                if(aboutBox == null) {
                    aboutBox = new Dialog(frame, "About Swing!", false);
                    JBufferedPane groupPanel = new JBufferedPane(new BorderLayout());
		    ImageIcon groupPicture = new ImageIcon("images/Copyright.gif");
                    aboutBox.add("Center", groupPanel);
                    groupPanel.add("Center", new JLabel(groupPicture));
                    JBufferedPane buttonPanel = (JBufferedPane) groupPanel.add("South", new JBufferedPane(true));
                    JButton button = (JButton) buttonPanel.add(new JButton("OK"));
                    button.addActionListener(new ActionListener() {
                        public void actionPerformed(ActionEvent e) {
                            aboutBox.setVisible(false);
                        }
                    });
                }
		aboutBox.pack();
		aboutBox.show();
	    }
	});

        file.add(new JSeparator());
        mi = (JMenuItem) file.add(new JMenuItem("Open"));
	mi.setEnabled(false);
        mi = (JMenuItem) file.add(new JMenuItem("Save"));
	mi.setEnabled(false);
        mi = (JMenuItem) file.add(new JMenuItem("Save As..."));
	mi.setEnabled(false);
        file.add(new JSeparator());
        mi = (JMenuItem) file.add(new JMenuItem("Exit"));
	mi.addActionListener(new ActionListener() {
	    public void actionPerformed(ActionEvent e) {
		System.exit(0);
	    }
	}
	);

	// Options Menu
	JMenu options = (JMenu) menuBar.add(new JMenu("Options"));
        cb = (JCheckBoxMenuItem) options.add(new JCheckBoxMenuItem("Show ToolTips"));
	cb.setSelected(true);
	ActionListener l = new ActionListener() {
	    public void actionPerformed(ActionEvent e) {
		if(cb.isSelected()) {
                    ToolTipManager.sharedInstance().setEnabled(true);
		} else {
                    ToolTipManager.sharedInstance().setEnabled(false);
		}
	    }
	};
	cb.addActionListener(l);

	// Authors Menu
	JMenu people = (JMenu) menuBar.add(new JMenu("Authors"));
        mi = (JMenuItem) people.add(new JMenuItem("Mark Andrews"));
        mi = (JMenuItem) people.add(new JMenuItem("Tom Ball"));
        mi = (JMenuItem) people.add(new JMenuItem("Alan Chung"));
        mi = (JMenuItem) people.add(new JMenuItem("Rob Davis"));
        mi = (JMenuItem) people.add(new JMenuItem("Jeff Dinkins"));
        mi = (JMenuItem) people.add(new JMenuItem("Amy Fowler"));
        mi = (JMenuItem) people.add(new JMenuItem("Brian Gerhold"));
        mi = (JMenuItem) people.add(new JMenuItem("James Gosling"));
        mi = (JMenuItem) people.add(new JMenuItem("David Karlton"));
        mi = (JMenuItem) people.add(new JMenuItem("Dave Kloba"));
        mi = (JMenuItem) people.add(new JMenuItem("Peter Korn"));
        mi = (JMenuItem) people.add(new JMenuItem("Philip Milne"));
        mi = (JMenuItem) people.add(new JMenuItem("Dave Moore"));
        mi = (JMenuItem) people.add(new JMenuItem("Hans Muller"));
        mi = (JMenuItem) people.add(new JMenuItem("Rick Levenson"));
        mi = (JMenuItem) people.add(new JMenuItem("Tim Prinzing"));
        mi = (JMenuItem) people.add(new JMenuItem("Chester Rose"));
        mi = (JMenuItem) people.add(new JMenuItem("Ray Ryan"));
        mi = (JMenuItem) people.add(new JMenuItem("Georges Saab"));
        mi = (JMenuItem) people.add(new JMenuItem("Scott Violet"));
        mi = (JMenuItem) people.add(new JMenuItem("Willie Walker"));
        mi = (JMenuItem) people.add(new JMenuItem("Kathy Walrath"));
        mi = (JMenuItem) people.add(new JMenuItem("Willie Walker"));
        mi = (JMenuItem) people.add(new JMenuItem("Arnaud Weber"));


	return menuBar;
    }

    /**
     * Menus
     */
    JMenuBar menuBar;

    JBufferedPane createMenus() {
	JBufferedPane p = createVerticalPanel(true);
	p.setInsets(insets10);

	// ********************
	// ***** MenuBar ******
	// ********************
	JLabel l = new JLabel("Menus:");
	l.setAlignmentX(LEFT_ALIGNMENT);
	l.setAlignmentY(TOP_ALIGNMENT);
	l.setFont(boldFont);
	p.add(l);
	p.add(Box.createRigidArea(vpad10));
	menuBar = new JMenuBar();
	menuBar.setAlignmentX(LEFT_ALIGNMENT);
	menuBar.setAlignmentY(TOP_ALIGNMENT);
	p.add(menuBar);
	p.add(Box.createRigidArea(vpad40));

	// File
	JMenu file = (JMenu) menuBar.add(new JMenu("File"));
	JMenuItem newItem =
	file.add(new JMenuItem("New", new ImageIcon("images/new.gif")));
	newItem.setHorizontalTextPosition(JButton.RIGHT);
	JMenuItem open = (JMenuItem)
	file.add(new JMenuItem("Open", new ImageIcon("images/open.gif")));
	open.setHorizontalTextPosition(JButton.RIGHT);
	JMenuItem save = (JMenuItem)
	file.add(new JMenuItem("Save", new ImageIcon("images/save.gif")));
	save.setHorizontalTextPosition(JButton.RIGHT);

	// Edit
	JMenu edit = (JMenu) menuBar.add(new JMenu("Edit"));
	JMenuItem cut = (JMenuItem)
	edit.add(new JMenuItem("Cut", new ImageIcon("images/cut.gif")));
	cut.setHorizontalTextPosition(JButton.RIGHT);
	JMenuItem copy = (JMenuItem)
	edit.add(new JMenuItem("Copy", new ImageIcon("images/copy.gif")));
	copy.setHorizontalTextPosition(JButton.RIGHT);
	JMenuItem paste = (JMenuItem)
	edit.add(new JMenuItem("Paste", new ImageIcon("images/paste.gif")));
	paste.setHorizontalTextPosition(JButton.RIGHT);

	// Letters
	JMenu letters = (JMenu) menuBar.add(new JMenu("Letters"));
        letters.add(new JMenuItem("A"));
        letters.add(new JMenuItem("B"));
        JMenu test2 = (JMenu) letters.add(new JMenu("C"));
        test2.add(new JMenuItem("C is for Cookie"));
        test2.add(new JMenuItem("C is for Cool"));
        JMenu test3 = (JMenu) test2.add(new JMenu("Our Cats:"));
        test3.add(new JCheckBoxMenuItem("Ridley"));
        test3.add(new JCheckBoxMenuItem("Quigley"));
        test3.add(new JMenuItem("Kizmet "));
	letters.add(new JMenuItem("D"));
	letters.add(new JMenuItem("E"));
	letters.add(new JMenuItem("F"));
	letters.add(new JMenuItem("G"));

	JMenu colors = (JMenu) menuBar.add(new JMenu("Colors"));
	colors.setHorizontalTextPosition(JButton.RIGHT);
	colors.setIcon(new ColoredSquare(Color.orange));
	menuBar.validate();

        JMenuItem red = colors.add(new JMenuItem("Red"));
	red.setHorizontalTextPosition(JButton.RIGHT);
	red.setIcon(new ColoredSquare(Color.red));

        JMenuItem blue = colors.add(new JMenuItem("Blue"));
	blue.setHorizontalTextPosition(JButton.RIGHT);
	blue.setIcon(new ColoredSquare(Color.blue));

        JMenuItem green = colors.add(new JMenuItem("Green"));
	green.setHorizontalTextPosition(JButton.RIGHT);
	green.setIcon(new ColoredSquare(Color.green));

        JMenuItem yellow = colors.add(new JMenuItem("Yellow"));
	yellow.setHorizontalTextPosition(JButton.RIGHT);
	yellow.setIcon(new ColoredSquare(Color.yellow));

	JMenu numbers = (JMenu) menuBar.add(new JMenu("Numbers"));
        numbers.add(new JMenuItem("1234"));
        numbers.add(new JMenuItem("1005"));
        numbers.add(new JMenuItem("2222"));

	JMenu drinks = (JMenu) menuBar.add(new JMenu("Drinks"));
        drinks.add(new JMenuItem("Thai Iced Tea"));
        drinks.add(new JMenuItem("Root Beer"));
        drinks.add(new JMenuItem("Green Tea"));
        drinks.add(new JMenuItem("Apple Juice"));
	drinks.addSeparator();
	ImageIcon softdrink = 
             new ImageIcon("images/ImageClub/food/softdrink.gif");
        drinks.add(new JMenuItem("Softdrink", softdrink));

	JMenu music = (JMenu) menuBar.add(new JMenu("Music"));
        music.add(new JMenuItem("Rock"));
        music.add(new JMenuItem("Country"));
        music.add(new JMenuItem("Classical"));
        music.add(new JMenuItem("Jazz"));

	JMenu food = (JMenu) menuBar.add(new JMenu("Junk Food"));
	ImageIcon burger = new ImageIcon("images/ImageClub/food/burger.gif");
	ImageIcon fries  = new ImageIcon("images/ImageClub/food/fries.gif");
	ImageIcon hotdog = new ImageIcon("images/ImageClub/food/hotdog.gif");
	ImageIcon pizza  = new ImageIcon("images/ImageClub/food/pizza.gif");

        addMenuItem(food, "Burger", burger);
	addMenuItem(food, "Fries", fries);
	addMenuItem(food, "Hotdog", hotdog);
	addMenuItem(food, "Pizza", pizza);

	// ********************
	// ****** ToolBar *****
	// ********************
	l = new JLabel("ToolBar:");
	l.setFont(boldFont);
	l.setAlignmentX(LEFT_ALIGNMENT);
	l.setAlignmentY(TOP_ALIGNMENT);
	p.add(l);
	p.add(Box.createRigidArea(vpad10));

	JBufferedPane p1 = (JBufferedPane)p.add(new JBufferedPane());
	p1.setAlignmentX(LEFT_ALIGNMENT);
	p1.setAlignmentY(TOP_ALIGNMENT);

	p1.setLayout(new FlowLayout(FlowLayout.LEFT));
	JToolBar toolBar = new JToolBar();
	addTool(toolBar, "new");
	addTool(toolBar, "open");
	addTool(toolBar, "save");
	toolBar.addSeparator();
	addTool(toolBar, "cut");
	addTool(toolBar, "copy");
	addTool(toolBar, "paste");

	p1.add(toolBar);
	return p;
    }

    void addMenuItem(JMenu menu, String text, Icon g) {
	JMenuItem mi = menu.add(new JMenuItem(text, g));
	mi.setHorizontalTextPosition(JButton.CENTER);
	mi.setHorizontalAlignment(JButton.LEFT);
	mi.setVerticalTextPosition(JButton.BOTTOM);
    }

    public void addTool(JToolBar toolBar, String name) {
	JButton b = 
           (JButton) toolBar.add(
               new JButton(new ImageIcon("images/" + name + ".gif")));
	b.setToolTipText(name);
	b.setPad(new Insets(0,0,0,0));
    }

    /**
     * SpringsAndStruts
     */
    JBufferedPane createSpringsAndStruts() {
	return new SpringsPane();
    }

    /**
     * Text
     */
    JBufferedPane createText() {
	return new JBufferedPane();
    }

    /**
     * Tab Listener
     */
    void createTabListener() {
	// add listener to know when we've been shown
        ChangeListener changeListener = new ChangeListener() {
            public void stateChanged(ChangeEvent e) {
                JTabbedPane tab = (JTabbedPane) e.getSource();
                int index = tab.getSelectedIndex();
                Component currentPage = tab.getComponentAt(index);

		if(!isBuffered()) {
		    setBuffered(true);
		}

		if(previousPage == debugGraphicsPanel) {
		    ((DebugGraphicsPanel)debugGraphicsPanel).resetAll();
		}

                if(currentPage == buttonPanel) {
		    currentControls = buttons;
		} else if(currentPage == radioButtonPanel) {
		    currentControls = radioButtons;
		} else if(currentPage == checkboxPanel) {
		    currentControls = checkboxes;
		} else if(currentPage == listBoxPanel) {
		    ((ListPanel)listBoxPanel).resetAll();
		} else if(currentPage == debugGraphicsPanel) {
		    setBuffered(false);
		    invalidate();
		    validate();
		} else if(currentPage == labelPanel) {
		    currentControls = labels;
                }
                previousPage = currentPage;
            }
        };
        tabbedPane.addChangeListener(changeListener);
    }



    /**
     *
     */
    JBufferedPane createToggleUIButtons() {
	JBufferedPane p = new JBufferedPane();
	p.setLayout(new BoxLayout(p, BoxLayout.Y_AXIS));
	p.setInsets(insets5);

	JLabel label = new JLabel("Look & Feel:");
	label.setFont(boldFont);

	JBufferedPane radioButtons = new JBufferedPane();
	radioButtons.setAlignmentX(LEFT_ALIGNMENT);
	radioButtons.setLayout(new BoxLayout(radioButtons, BoxLayout.X_AXIS));

	ToggleUIListener toggleUIListener = new ToggleUIListener();
	ButtonGroup group = new ButtonGroup();

	radioButtons.add(Box.createRigidArea(hpad20));

	JRadioButton basic = new JRadioButton("Win 95 Style");
	basic.addItemListener(toggleUIListener);
	group.add(basic);
	basic.setSelected(true);
        basic.setKeyAccelerator('w');
	radioButtons.add(basic);

	radioButtons.add(Box.createRigidArea(hpad20));

	JRadioButton rose = new JRadioButton("Rose");
	group.add(rose);
	rose.addItemListener(toggleUIListener);
        rose.setKeyAccelerator('r');
	radioButtons.add(rose);

	p.add(Box.createRigidArea(vpad5));
	p.add(label);
	p.add(Box.createRigidArea(vpad5));
	p.add(radioButtons);
	p.add(Box.createRigidArea(vpad5));

	return p;
    }

    /**
     * create Logo
     */
    JBufferedPane createLogo() {
	JBufferedPane p = new JBufferedPane();
	ImageIcon logo = new ImageIcon("images/AboutSwing.gif");
	p.add(new JLabel(logo));
	return p;
    }


    public static void main(String s[]) {
        String vers = System.getProperty("java.version");
        if (vers.compareTo("1.1.2") < 0) {
            System.out.println("!!!WARNING: Swing must be run with a " +
                               "1.1.2 or higher version VM!!!");
        }
	WindowListener l = new WindowAdapter() {
	    public void windowClosing(WindowEvent e) {System.exit(0);}
	};

	frame = new JFrame("SwingSet");
	frame.setForeground(Color.black);
	frame.setBackground(Color.lightGray);
	frame.addWindowListener(l);
	frame.getContentPane().setLayout(
		new BoxLayout(frame.getContentPane(), BoxLayout.X_AXIS));

	JBufferedPane progressPanel = createVerticalPanel(false);
	frame.getContentPane().add(Box.createGlue());
	frame.getContentPane().add(progressPanel);
	frame.getContentPane().add(Box.createGlue());


	progressPanel.add(Box.createGlue());

	Dimension d = new Dimension(400, 20);
	SwingSet.progressLabel = new JLabel("Loading, please wait...");
	SwingSet.progressLabel.setMaximumSize(d);
	progressPanel.add(progressLabel);
	progressPanel.add(Box.createRigidArea(new Dimension(1,20)));

	SwingSet.progressBar = new JProgressBar();
	SwingSet.progressBar.setMaximumSize(d);
	SwingSet.progressBar.setMinimum(0);
	SwingSet.progressBar.setMaximum(SwingSet.totalPanels);
	SwingSet.progressBar.setValue(0);
	progressPanel.add(SwingSet.progressBar);
	progressPanel.add(Box.createGlue());

	progressPanel.add(Box.createGlue());

        try {
            UIManager.setUIFactory(
                "com.sun.java.swing.basic.BasicFactory", frame);
        } catch (ClassNotFoundException cnf) {
        }

	// show the frame
	frame.setSize(INITIAL_WIDTH, INITIAL_HEIGHT);
	Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
	frame.setLocation(screenSize.width/2 - INITIAL_WIDTH/2,
			  screenSize.height/2 - INITIAL_HEIGHT/2);
	frame.show();

        frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));

	SwingSet sw = new SwingSet();
	frame.getContentPane().removeAll();
	frame.getContentPane().setLayout(new BorderLayout());
	frame.getContentPane().add("Center", sw);
	frame.setLocation(screenSize.width/2 - WIDTH/2,
			  screenSize.height/2 - HEIGHT/2);

	frame.setSize(WIDTH, HEIGHT);
	frame.setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));

	frame.validate();
	frame.repaint();
        sw.requestDefaultFocus();
    }


    // Position
    void setNWposition(AbstractButton b) {b.setHorizontalTextPosition(AbstractButton.LEFT);   b.setVerticalTextPosition(AbstractButton.TOP);}
    void setNposition(AbstractButton b)  {b.setHorizontalTextPosition(AbstractButton.CENTER); b.setVerticalTextPosition(AbstractButton.TOP);}
    void setNEposition(AbstractButton b) {b.setHorizontalTextPosition(AbstractButton.RIGHT);  b.setVerticalTextPosition(AbstractButton.TOP);}
    void setWposition(AbstractButton b)  {b.setHorizontalTextPosition(AbstractButton.LEFT);   b.setVerticalTextPosition(AbstractButton.CENTER);}
    void setCposition(AbstractButton b)  {b.setHorizontalTextPosition(AbstractButton.CENTER); b.setVerticalTextPosition(AbstractButton.CENTER);}
    void setEposition(AbstractButton b)  {b.setHorizontalTextPosition(AbstractButton.RIGHT);  b.setVerticalTextPosition(AbstractButton.CENTER);}
    void setSWposition(AbstractButton b) {b.setHorizontalTextPosition(AbstractButton.LEFT);   b.setVerticalTextPosition(AbstractButton.BOTTOM);}
    void setSposition(AbstractButton b)  {b.setHorizontalTextPosition(AbstractButton.CENTER); b.setVerticalTextPosition(AbstractButton.BOTTOM);}
    void setSEposition(AbstractButton b) {b.setHorizontalTextPosition(AbstractButton.RIGHT);  b.setVerticalTextPosition(AbstractButton.BOTTOM);}

    void setNWposition(JLabel b) {b.setHorizontalTextPosition(JLabel.LEFT);   b.setVerticalTextPosition(JLabel.TOP);}
    void setNposition(JLabel b)  {b.setHorizontalTextPosition(JLabel.CENTER); b.setVerticalTextPosition(JLabel.TOP);}
    void setNEposition(JLabel b) {b.setHorizontalTextPosition(JLabel.RIGHT);  b.setVerticalTextPosition(JLabel.TOP);}
    void setWposition(JLabel b)  {b.setHorizontalTextPosition(JLabel.LEFT);   b.setVerticalTextPosition(JLabel.CENTER);}
    void setCposition(JLabel b)  {b.setHorizontalTextPosition(JLabel.CENTER); b.setVerticalTextPosition(JLabel.CENTER);}
    void setEposition(JLabel b)  {b.setHorizontalTextPosition(JLabel.RIGHT);  b.setVerticalTextPosition(JLabel.CENTER);}
    void setSWposition(JLabel b) {b.setHorizontalTextPosition(JLabel.LEFT);   b.setVerticalTextPosition(JLabel.BOTTOM);}
    void setSposition(JLabel b)  {b.setHorizontalTextPosition(JLabel.CENTER); b.setVerticalTextPosition(JLabel.BOTTOM);}
    void setSEposition(JLabel b) {b.setHorizontalTextPosition(JLabel.RIGHT);  b.setVerticalTextPosition(JLabel.BOTTOM);}

    // Alignment
    void setNWalignment(AbstractButton b) {b.setHorizontalAlignment(AbstractButton.LEFT);   b.setVerticalAlignment(AbstractButton.TOP);}
    void setNalignment(AbstractButton b)  {b.setHorizontalAlignment(AbstractButton.CENTER); b.setVerticalAlignment(AbstractButton.TOP);}
    void setNEalignment(AbstractButton b) {b.setHorizontalAlignment(AbstractButton.RIGHT);  b.setVerticalAlignment(AbstractButton.TOP);}
    void setWalignment(AbstractButton b)  {b.setHorizontalAlignment(AbstractButton.LEFT);   b.setVerticalAlignment(AbstractButton.CENTER);}
    void setCalignment(AbstractButton b)  {b.setHorizontalAlignment(AbstractButton.CENTER); b.setVerticalAlignment(AbstractButton.CENTER);}
    void setEalignment(AbstractButton b)  {b.setHorizontalAlignment(AbstractButton.RIGHT);  b.setVerticalAlignment(AbstractButton.CENTER);}
    void setSWalignment(AbstractButton b) {b.setHorizontalAlignment(AbstractButton.LEFT);   b.setVerticalAlignment(AbstractButton.BOTTOM);}
    void setSalignment(AbstractButton b)  {b.setHorizontalAlignment(AbstractButton.CENTER); b.setVerticalAlignment(AbstractButton.BOTTOM);}
    void setSEalignment(AbstractButton b) {b.setHorizontalAlignment(AbstractButton.RIGHT);  b.setVerticalAlignment(AbstractButton.BOTTOM);}

    void setNWalignment(JLabel b) {b.setHorizontalAlignment(JLabel.LEFT);   b.setVerticalAlignment(JLabel.TOP);}
    void setNalignment(JLabel b)  {b.setHorizontalAlignment(JLabel.CENTER); b.setVerticalAlignment(JLabel.TOP);}
    void setNEalignment(JLabel b) {b.setHorizontalAlignment(JLabel.RIGHT);  b.setVerticalAlignment(JLabel.TOP);}
    void setWalignment(JLabel b)  {b.setHorizontalAlignment(JLabel.LEFT);   b.setVerticalAlignment(JLabel.CENTER);}
    void setCalignment(JLabel b)  {b.setHorizontalAlignment(JLabel.CENTER); b.setVerticalAlignment(JLabel.CENTER);}
    void setEalignment(JLabel b)  {b.setHorizontalAlignment(JLabel.RIGHT);  b.setVerticalAlignment(JLabel.CENTER);}
    void setSWalignment(JLabel b) {b.setHorizontalAlignment(JLabel.LEFT);   b.setVerticalAlignment(JLabel.BOTTOM);}
    void setSalignment(JLabel b)  {b.setHorizontalAlignment(JLabel.CENTER); b.setVerticalAlignment(JLabel.BOTTOM);}
    void setSEalignment(JLabel b) {b.setHorizontalAlignment(JLabel.RIGHT);  b.setVerticalAlignment(JLabel.BOTTOM);}

    /**
     * Toggle the L&F between Basic and Rose
     */
    class ToggleUIListener implements ItemListener {
	public void itemStateChanged(ItemEvent e) {
	    frame.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
	    JRadioButton b = (JRadioButton) e.getSource();
	    if(b.getText().equals("Win 95 Style")) {
		setBasic();
		currentUI = "Basic";
	    } else if(b.getText().equals("Rose")) {
		currentUI = "Rose";
		setRose();
	    }
	    frame.invalidate();
	    frame.validate();
	    frame.repaint();
	    frame.setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
	}

    }

    public void setRose() {
	try {
	    UIManager.setUIFactory(
		"com.sun.java.swing.rose.RoseFactory", frame);
	} catch (java.lang.ClassNotFoundException e) {
	    System.out.println(e);
	}
    }

    public void setBasic() {
	try {
	    UIManager.setUIFactory(
		"com.sun.java.swing.basic.BasicFactory", frame);
	} catch (java.lang.ClassNotFoundException e) {
	    System.out.println(e);
	}
    }

    // ***********************************************************
    // *********** Create the button controls listeners **********
    // ***********************************************************
    ActionListener sizeListener = new ActionListener() {
	public void actionPerformed(ActionEvent e) {
	    JRadioButton rb = (JRadioButton) e.getSource();
	    AbstractButton button;
	    if(rb.isSelected()) {
		boolean b = rb.getText().equals("PreferredSize");
		for(int i = 0; i < currentControls.size(); i++) {
		    button = (AbstractButton) currentControls.elementAt(i);
		    button.setMaxSizeEqualsPrefSize(b);
		}
		int index = tabbedPane.getSelectedIndex();
		Component currentPage = tabbedPane.getComponentAt(index);
		currentPage.invalidate();
		currentPage.validate();
		currentPage.repaint();
	    }
	}
    };

    ItemListener buttonPadListener = new ItemListener() {
	Component c;
	AbstractButton b;

	public void itemStateChanged(ItemEvent e) {
	    // *** pad = 0
	    int pad = 0;
	    JRadioButton rb = (JRadioButton) e.getSource();
	    if(rb.getText().equals("Default")) {
		for(int i = 0; i < currentControls.size(); i++) {
		    b = (AbstractButton) currentControls.elementAt(i);
	            // *** pad = Default
		    b.setPad(null);
		}
		int index = tabbedPane.getSelectedIndex();
		Component currentPage = tabbedPane.getComponentAt(index);
		currentPage.invalidate();
		currentPage.validate();
		currentPage.repaint();
		return;
	    } else if(rb.getText().equals("10")) {
	        // pad = 10
		pad = 10;
	    }

	    for(int i = 0; i < currentControls.size(); i++) {
		b = (AbstractButton) currentControls.elementAt(i);
		b.setPad(new Insets(pad,pad,pad,pad));
	    }
	    int index = tabbedPane.getSelectedIndex();
	    Component currentPage = tabbedPane.getComponentAt(index);
	    currentPage.invalidate();
	    currentPage.validate();
	    currentPage.repaint();
	}
    };

    ItemListener buttonDisplayListener = new ItemListener() {
	Component c;
	AbstractButton b;

	public void itemStateChanged(ItemEvent e) {
	    JCheckBox cb = (JCheckBox) e.getSource();
	    if(cb.getText().equals("Enabled")) {
		for(int i = 0; i < currentControls.size(); i++) {
		    c = (Component) currentControls.elementAt(i);
		    c.setEnabled(cb.isSelected());
		    c.invalidate();
		}
	    } else if(cb.getText().equals("Paint Border")) {
		c = (Component) currentControls.elementAt(0);
		if(c instanceof AbstractButton) {
		    for(int i = 0; i < currentControls.size(); i++) {
			b = (AbstractButton) currentControls.elementAt(i);
			b.setBorderPainted(cb.isSelected());
		        b.invalidate();
		    }
		}
	    } else if(cb.getText().equals("Paint Focus")) {
		c = (Component) currentControls.elementAt(0);
		if(c instanceof AbstractButton) {
		    for(int i = 0; i < currentControls.size(); i++) {
			b = (AbstractButton) currentControls.elementAt(i);
			b.setFocusPainted(cb.isSelected());
		        b.invalidate();
		    }
		}
	    }
	    int index = tabbedPane.getSelectedIndex();
	    Component currentPage = tabbedPane.getComponentAt(index);
	    currentPage.invalidate();
	    currentPage.validate();
	    currentPage.repaint();
	}
    };

    // Text Position
    ActionListener textPositionListener = new ActionListener() {
	public void actionPerformed(ActionEvent e) {
	    JRadioButton rb = (JRadioButton) e.getSource();
	    if(rb.isSelected()) {
		if(rb.getActionCommand().equals("NW")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setNWposition(x);
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setNWposition(x);
			}
		    }
		} else if(rb.getActionCommand().equals("N")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setNposition(x);
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setNposition(x);
			}
		    }
		} else if(rb.getActionCommand().equals("NE")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setNEposition(x);
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setNEposition(x);
			}
		    }
		} else if(rb.getActionCommand().equals("W")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setWposition(x);
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setWposition(x);
			}
		    }
		} else if(rb.getActionCommand().equals("C")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setCposition(x);
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setCposition(x);
			}
		    }
		} else if(rb.getActionCommand().equals("E")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setEposition(x);
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setEposition(x);
			}
		    }
		} else if(rb.getActionCommand().equals("SW")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setSWposition(x);
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setSWposition(x);
			}
		    }
		} else if(rb.getActionCommand().equals("S")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setSposition(x);
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setSposition(x);
			}
		    }
		} else if(rb.getActionCommand().equals("SE")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setSEposition(x);
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setSEposition(x);
			}
		    }
		}
		int index = tabbedPane.getSelectedIndex();
                Component currentPage = tabbedPane.getComponentAt(index);
		currentPage.invalidate();
		currentPage.validate();
		currentPage.repaint();
	    } else {
	    }
	}
    };


    // Label Alignment
    ActionListener labelAlignmentListener = new ActionListener() {
	public void actionPerformed(ActionEvent e) {
	    JRadioButton rb = (JRadioButton) e.getSource();
	    if(rb.isSelected()) {
		if(rb.getActionCommand().equals("NW")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setNWalignment(x);
			    x.invalidate();
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setNWalignment(x);
			    x.invalidate();
			}
		    }
		} else if(rb.getActionCommand().equals("N")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setNalignment(x);
			    x.invalidate();
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setNalignment(x);
			    x.invalidate();
			}
		    }
		} else if(rb.getActionCommand().equals("NE")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setNEalignment(x);
			    x.invalidate();
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setNEalignment(x);
			    x.invalidate();
			}
		    }
		} else if(rb.getActionCommand().equals("W")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setWalignment(x);
			    x.invalidate();
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setWalignment(x);
			    x.invalidate();
			}
		    }
		} else if(rb.getActionCommand().equals("C")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setCalignment(x);
			    x.invalidate();
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setCalignment(x);
			    x.invalidate();
			}
		    }
		} else if(rb.getActionCommand().equals("E")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setEalignment(x);
			    x.invalidate();
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setEalignment(x);
			    x.invalidate();
			}
		    }
		} else if(rb.getActionCommand().equals("SW")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setSWalignment(x);
			    x.invalidate();
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setSWalignment(x);
			    x.invalidate();
			}
		    }
		} else if(rb.getActionCommand().equals("S")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setSalignment(x);
			    x.invalidate();
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setSalignment(x);
			    x.invalidate();
			}
		    }
		} else if(rb.getActionCommand().equals("SE")) {
		    for(int i = 0; i < currentControls.size(); i++) {
			Component c = (Component) currentControls.elementAt(i);
			if(c instanceof AbstractButton) {
			    AbstractButton x = (AbstractButton) c;
			    setSEalignment(x);
			    x.invalidate();
			} else if(c instanceof JLabel) {
			    JLabel x = (JLabel) c;
			    setSEalignment(x);
			    x.invalidate();
			}
		    }
		}
		int index = tabbedPane.getSelectedIndex();
                Component currentPage = tabbedPane.getComponentAt(index);
		currentPage.invalidate();
		currentPage.validate();
		currentPage.repaint();
	    }
	}
    };

    // Title Pane tile position
    ActionListener borderedPaneListener = new ActionListener() {
	public void actionPerformed(ActionEvent e) {
	    JRadioButton b = (JRadioButton) e.getSource();
	    if(b.getText().equals("Above Top")) {((TitledBorder)borderedPane.getBorder()).setTitlePosition(TitledBorder.ABOVE_TOP);}
	    if(b.getText().equals("Top")) {((TitledBorder)borderedPane.getBorder()).setTitlePosition(TitledBorder.TOP);}
	    if(b.getText().equals("Below Top")) {((TitledBorder)borderedPane.getBorder()).setTitlePosition(TitledBorder.BELOW_TOP);}

	    if(b.getText().equals("Above Bottom")) {((TitledBorder)borderedPane.getBorder()).setTitlePosition(TitledBorder.ABOVE_BOTTOM);}
	    if(b.getText().equals("Bottom")) {((TitledBorder)borderedPane.getBorder()).setTitlePosition(TitledBorder.BOTTOM);}
	    if(b.getText().equals("Below Bottom")) {((TitledBorder)borderedPane.getBorder()).setTitlePosition(TitledBorder.BELOW_BOTTOM);}

	    if(b.getText().equals("Left")) {((TitledBorder)borderedPane.getBorder()).setTitleJustification(TitledBorder.LEFT);}
	    if(b.getText().equals("Center")) {((TitledBorder)borderedPane.getBorder()).setTitleJustification(TitledBorder.CENTER);}
	    if(b.getText().equals("Right")) {((TitledBorder)borderedPane.getBorder()).setTitleJustification(TitledBorder.RIGHT);}

	    borderedPane.invalidate();
	    borderedPane.validate();
	    borderedPane.repaint();
	}
    };

    class BigScrollPane extends JScrollPane {
	public BigScrollPane() {
	    super();
	    getViewport().add(new JLabel(tiger));
	}

	public Dimension getMinimumSize() {
	    return new Dimension(25, 25);
	}
    }

    public static JBufferedPane createHorizontalPanel(boolean threeD) {
	JBufferedPane p = new JBufferedPane();
	p.setLayout(new BoxLayout(p, BoxLayout.X_AXIS));
	if(threeD) {
	    p.setBorderStyle(LOWERED);
	}
	return p;
    }

    public static JBufferedPane createVerticalPanel(boolean threeD) {
	JBufferedPane p = new JBufferedPane();
	p.setLayout(new BoxLayout(p, BoxLayout.Y_AXIS));
	if(threeD) {
	    p.setBorderStyle(LOWERED);
	}
	return p;
    }

    public static String contentsOfFile(String filename) {
	String s = new String();
	File f = new File(filename);
	char[] buff = new char[50000];
	Reader in;

	try {
	    in = new FileReader(f);
	    int nch;
	    while ((nch = in.read(buff, 0, buff.length)) != -1) {
		s = s + new String(buff, 0, nch);
	    }
	} catch (java.io.IOException ex) {
	    s = "Could not load file: " + filename;
	}

	return s;
    }

    class ColoredSquare implements Icon {
	Color color;
	public ColoredSquare(Color c) {
	    this.color = c;
	}

	public void paint(Graphics g, int x, int y) {
	    Color oldColor = g.getColor();
	    g.setColor(color);
	    g.fill3DRect(x,y,getWidth(), getHeight(), true);
	    g.setColor(oldColor);
	}
	public int getWidth() { return 12; }
	public int getHeight() { return 12; }

    }
}
