/*
 * @(#)TablePanel.java	1.14 97/08/28
 *
 * Copyright (c) 1997 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 *
 */

import com.sun.java.swing.*;
import com.sun.java.swing.table.*;

import java.awt.*;
import java.awt.event.*;
import java.lang.*;

/*
 * @version 1.14 08/28/97
 * @author Alan Chung
 * @author Jeff Dinkins
 */
public class TablePanel extends JBufferedPane {
    JTable table;
    TableModel dataModel;

    public TablePanel(SwingSet swing) {
	super();
	setLayout(new BorderLayout());

	setInsets(new Insets(5,5,5,5));
	
        // Create the dummy data (a few rows of names)
        final Object[][] data = {
            {"First Name",
	     "Mark",  // Andrews
	     "Tom",   // Ball
	     "Alan",  // Chung
	     "Jeff",  // Dinkins
	     "Amy",   // Fowler
	     "Brian", // Gerhold
	     "James", // Gosling
	     "David", // Karlton
	     "Dave",  // Kloba
	     "Peter", // Korn
	     "Dave",  // Moore
	     "Hans",  // Muller
	     "Rick",  // Levenson
	     "Tim",   // Prinzing
	     "Chester", // Rose
	     "Ray",     // Ryan
	     "Georges", // Saab
	     "Willie",  // Walker
	     "Kathy",   // Walrath
	     "Arnaud"   // Weber
	    },
            {"Last Name",
	     "Andrews",
	     "Ball",
	     "Chung",
	     "Dinkins",
	     "Fowler",
	     "Gerhold",
	     "Gosling",
	     "Karlton",
	     "Kloba",
	     "Korn",
	     "Moore",
	     "Muller", 
	     "Levenson",
	     "Prinzing",
	     "Rose",
	     "Ryan",
	     "Saab",
	     "Walker",
	     "Walrath",
	     "Weber"
	    },
            {"Favorite Color",
	     "Red",    // Andrews
	     "Blue",   // Ball
	     "Green",  // Chung
	     "Turquoise",  // Dinkins
	     "Yellow", // Fowler
	     "Green", // Gerhold
	     "Pink",   // Gosling
	     "Red",    // Karlton
	     "Yellow", // Kloba
	     "Purple", // Korn
	     "Green",  // Moore
	     "Maroon", // Muller
	     "Blue",   // Levenson
	     "Blue",   // Prinzing
	     "Black",  // Rose
	     "Gray",   // Ryan
	     "Red",    // Saab
	     "Phthalo Blue",  // Walker
	     "Blue",   // Walrath
	     "Green"   // Weber
	    },
            {"Favorite Number",
	     "2",  // Andrews
	     "99", // Ball
	     "11", // Chung
	     "8",  // Dinkins
	     "3",  // Fowler
	     "0",  // Gerhold
	     "21", // Gosling
	     "1",  // Karlton
	     "14", // Kloba
	     "12", // Korn
	     "88", // Moore
	     "5",  // Muller
	     "2",  // Levenson
	     "22", // Prinzing
	     "0",  // Rose
	     "77", // Ryan
	     "4",  // Saab
	     "4",  // Walker
	     "8",  // Walrath
	     "44"  // Weber
	    },
            {"Vegetarian",
	     new Boolean(true),  // Andrews
	     new Boolean(false), // Ball
	     new Boolean(false), // Chung
	     new Boolean(true),  // Dinkins
	     new Boolean(false), // Fowler
	     new Boolean(false), // Gerhold
	     new Boolean(false), // Gosling
	     new Boolean(false), // Karlton
	     new Boolean(false), // Korn
	     new Boolean(false), // Kloba
	     new Boolean(false), // Moore
	     new Boolean(false), // Muller
	     new Boolean(false), // Levenson
	     new Boolean(false), // Prinzing
	     new Boolean(false), // Rose
	     new Boolean(false), // Ryan
	     new Boolean(false), // Saab
	     new Boolean(false), // Violet
	     new Boolean(false), // Walker
	     new Boolean(false), // Walrath
	     new Boolean(false)  // Weber
	    }
        };
 
        // Create the table data model
        dataModel = new AbstractTableModel() {
            public int getRowCount() { return data[0].length - 1; }
            public Object getValueAt(Object columnIdentifier, int rowIndex) {
                // Check the columnIdentifier against the first row for match
                for (int columnIndex = 0; columnIndex < data.length; columnIndex ++){
                    if (data[columnIndex][0].equals(columnIdentifier)) {
                        return data[columnIndex][rowIndex+1];
                    }
                }
                return "<Empty>";
            }
            public void setValueAt(Object aValue, Object columnIdentifier,
                                   int rowIndex) {
                // Check the columnIdentifier against the first row for match
                for (int columnIndex = 0; columnIndex < data.length; columnIndex ++){
                    if (data[columnIndex][0].equals(columnIdentifier)) {
                        data[columnIndex][rowIndex+1] = aValue;
                    }
                }
                // PENDING(alan): Throw if columnId not found
            }
        };
 
        // Create the table
        table = new JTable(dataModel);
 
        // Added our columns into the  column model
        for (int columnIndex = 0; columnIndex < data.length; columnIndex++){
            // Create a column object for each column of data
            TableColumn newColumn = new TableColumn(data[columnIndex][0]);
	    if(columnIndex < 2) {
		newColumn.setWidth(100);
	    } else if(columnIndex < 4) {
		newColumn.setWidth(140);
	    } else {
		newColumn.setWidth(110);
	    }
 
            // Set the renderer and editor for the boolean column
            if (newColumn.getIdentifier().equals("Vegetarian")) {
                newColumn.setCellRenderer(new DefaultCellRenderer(new JCheckBox()));
                newColumn.setCellEditor(new DefaultCellEditor(new JCheckBox()));
            }
	    else {
                newColumn.setCellEditor(new DefaultCellEditor(new JTextField("")));
	    }
 
            table.addColumn(newColumn);
        }

        // Put the table and header into a scrollPane
        JScrollPane scrollpane = new JScrollPane();
        JTableHeader tableHeader = table.getTableHeader();

	// create and add the column heading to the scrollpane's
	// column header viewport
        JViewport headerViewport = new JViewport();
	headerViewport.setLayout(new BoxLayout(headerViewport, BoxLayout.X_AXIS));
	headerViewport.add(tableHeader);
	scrollpane.setColumnHeading(headerViewport);

	// add the table to the viewport
        JViewport mainViewPort = scrollpane.getViewport();
        mainViewPort.add(table);

        // speed up resizing repaints by turning off live cell updates
        tableHeader.setUpdateTableInRealTime(false);
 
        add(scrollpane, BorderLayout.CENTER);
    }
}
