/*
 * @(#)TreeCombo.java	1.7 97/08/26
 * 
 * Copyright (c) 1997 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 * 
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 * 
 */
import com.sun.java.swing.*;
import com.sun.java.swing.event.*;
import com.sun.java.swing.basic.*;
import java.util.Vector;
import java.awt.*;
import com.sun.java.swing.plaf.*;

public class TreeCombo extends JComboBox {
    static final int OFFSET = 16;

    public TreeCombo(TreeModel aTreeModel) {
        super();
        setModel(new TreeToListModel(aTreeModel));
        super.setUI(new TreeComboUI());
        setRenderer(new ListEntryRenderer());
    }

    public void setUI(ComboBoxUI ui) {
        /* The ui of this component cannot change */
    }

    class TreeToListModel extends AbstractListModel implements ComboBoxModel,TreeModelListener {
        TreeModel source;
        boolean invalid = true;
        Object currentValue;
        Vector cache = new Vector();

        public TreeToListModel(TreeModel aTreeModel) {
            source = aTreeModel;
            aTreeModel.addTreeModelListener(this);
            setRenderer(new ListEntryRenderer());
        }

        public void setCurrentValue(Object anObject) {
            currentValue = anObject;
            notifyListDataListeners(new ListDataEvent(this,ListDataEvent.CONTENTS_CHANGED,-1,-1));
        }

        public Object getCurrentValue() {
            return currentValue;
        }

        public int getSize() {
            validate();
            return cache.size();
        }

        public Object getElementAt(int index) {
            return cache.elementAt(index);
        }

        public void treeNodesChanged(TreeModelEvent e) {
            invalid = true;
        }

        public void treeNodesInserted(TreeModelEvent e) {
            invalid = true;
        }

        public void treeNodesRemoved(TreeModelEvent e) {
            invalid = true;
        }

        public void treeStructureChanged(TreeModelEvent e) {
            invalid = true;
        }

        void validate() {
            if(invalid) {
                cache = new Vector();
                cacheTree(source.getRoot(),0);
                if(cache.size() > 0)
                    currentValue = cache.elementAt(0);
                invalid = false;             
                notifyListDataListeners(new ListDataEvent(this,ListDataEvent.CONTENTS_CHANGED,0,0));
            }
        }

        void cacheTree(Object anObject,int level) {
            if(source.isLeaf(anObject))
                addListEntry(anObject,level,false);
            else {
                int c = source.getChildCount(anObject);
                int i;
                Object child;

                addListEntry(anObject,level,true);
                level++;

                for(i=0;i<c;i++) {
                    child = source.getChild(anObject,i);
                    cacheTree(child,level);
                }

                level--;
            }
        }

        void addListEntry(Object anObject,int level,boolean isNode) {
            cache.addElement(new ListEntry(anObject,level,isNode));
        }
    }

    class ListEntry {
        Object object;
        int    level;
        boolean isNode;

        public ListEntry(Object anObject,int aLevel,boolean isNode) {
            object = anObject;
            level = aLevel;
            this.isNode = isNode;
        }

        public Object object() {
            return object;
        }

        public int level() {
            return level;
        }

        public boolean isNode() {
            return isNode;
        }
    }


    class ListEntryRenderer extends JLabel implements ListCellRenderer 
    {
        ImageIcon leafIcon = new ImageIcon("images/document.gif");
        ImageIcon nodeIcon = new ImageIcon("images/folder.gif");

        public void configureListCellRenderer(Object value, int index) {
            ListEntry listEntry = (ListEntry)value;
	    boolean selected = (value == getCurrentValue());

            if(listEntry != null) {
                int offsets;
                setText(listEntry.object().toString());
		setIcon( listEntry.isNode() ? nodeIcon : leafIcon );
                if(index != -1)
                    offsets = OFFSET * listEntry.level();
                else 
                    offsets = 0;
		setInsets(new Insets(0, offsets, 0, 0)); 
            } else {
                setText("");
            }
	}

	public Component getListCellRendererComponent() {
	    return this;
	}
    }


    class TreeComboUI extends BasicComboBoxUI {
        protected JListBox createListBox(ComboBoxModel m) {
            JListBox res = new JListBox(m);
            res.setCellRenderer(new ListEntryRenderer());
            return res;
        }
    }
}


